import { useRef, useState } from 'react';
import CustomElement from '../src/lib/customElement';
import Divider from '../src/lib/divider/divider';
import Tooltip from '../src/lib/tooltip/tooltip';

export const parameters = {
  controls: { expanded: true },
};

export const decorators = [
  (Story, context) => {
    const [inWebComponent, setInWebComponent] = useState(false);
    console.log('context', context);
    const head = document.head.cloneNode(true);
    if (customElements.get('custom-element') === undefined) {
      customElements.define('custom-element', CustomElement);
    }
    const story = document.createElement('custom-element');
    story.params = { story: Story, head: head, context: context };
    const inputRef = useRef(null);
    function toggle() {
      console.log(
        'toggle',
        inWebComponent,
        inputRef.current,
        inputRef.current.checked
      );
      const checked = inputRef.current.checked;
      setInWebComponent(checked);
    }
    return (
      <>
        <label
          onClick={toggle}
          style={{ display: 'flex', alignItems: 'center' }}
        >
          <input type="checkbox" ref={inputRef} /> render in custom web
          component
          <Tooltip message="Story render within a custom web component to test component behaviour in shadow root. It should be helpful in testing and development of component and events within, which use global window/document object methods such as document.getElementById()"></Tooltip>
        </label>
        <Divider styleType="dashed" thickness={2} color="black" />
        <br />
        {inWebComponent ? (
          <div
            ref={(nodeElement) => {
              nodeElement && nodeElement.appendChild(story);
            }}
          />
        ) : (
          <Story {...context} />
        )}
      </>
    );
  },
];
