import { Meta } from '@storybook/react';
import { AppbarInput } from './appbar-input';
import { useState } from 'react';
import { filterBy } from '@progress/kendo-data-query';
import styled from 'styled-components';

export default {
  component: AppbarInput,
  title: 'Inputs/AppbarInput',
} as Meta;

const StyledContainer = styled.div`
  margin-top: 20px;
  & > div > span {
    margin-left: 30px;
    color: red;
  }
`;

const countries = [
  'Albania',
  'Belarus',
  'Croatia',
  'Denmark',
  'Estonia',
  'Finland',
  'Georgia',
  'Hungary',
  'Ireland',
  'Kosovo',
  'Latvia',
  'Macedonia',
  'Norway',
  'Poland',
  'Romania',
  'San Marino',
  'Turkey',
  'Ukraine',
  'Vatican City',
];

export const Primary = ({ ...args }) => {
  const [autoCompleteState, setAutoCompleteState] = useState({
    data: countries,
    value: '',
  });

  const [dropDownState, setDropDownState] = useState('');

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const handleAutoCompleteChange = (e) => {
    const value = e.value;
    setAutoCompleteState({
      data: filterData(value),
      value: value,
    });
  };

  const handleOnDropdownChange = (e) => setDropDownState(e.target.value);

  console.log(autoCompleteState.value);

  return (
    <>
      <AppbarInput
        defaultDropdownItem="Purchase Order"
        id="appbar-id"
        placeholderAutoComplete="e.g. Ireland"
        dropDownData={['first', 'second', 'last']}
        autoCompleteData={autoCompleteState.data}
        autoCompleteValue={autoCompleteState.value}
        onAutoCompleteChange={handleAutoCompleteChange}
        onDropdownChange={handleOnDropdownChange}
        {...args}
      />

      <StyledContainer>
        <div>
          Autocomplete Value: <span>{autoCompleteState.value}</span>
        </div>
        <div>
          Dropdown Value: <span>{dropDownState}</span>
        </div>
      </StyledContainer>
    </>
  );
};

export const DisabledAutoComplete = ({ ...args }) => {
  const handleOnDropdownChange = (e) => console.log(e.target.value);

  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (e) => {
    const value = e.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <AppbarInput
      defaultDropdownItem="Purchase Order"
      id="appbar-id"
      placeholderAutoComplete="e.g. Ireland"
      dropDownData={['first', 'second', 'last']}
      autoCompleteData={state.data}
      autoCompleteValue={state.value}
      onAutoCompleteChange={onChange}
      onDropdownChange={handleOnDropdownChange}
      disabledAutoComplete={true}
      {...args}
    />
  );
};

export const DisabledDropdown = ({ ...args }) => {
  const handleOnDropdownChange = (e) => console.log(e.target.value);

  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (e) => {
    const value = e.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <AppbarInput
      defaultDropdownItem="Purchase Order"
      id="appbar-id"
      placeholderAutoComplete="e.g. Ireland"
      dropDownData={['first', 'second', 'last']}
      autoCompleteData={state.data}
      autoCompleteValue={state.value}
      onAutoCompleteChange={onChange}
      onDropdownChange={handleOnDropdownChange}
      disabledDropdown={true}
      {...args}
    />
  );
};

export const Error = ({ ...args }) => {
  const handleOnDropdownChange = (e) => console.log(e.target.value);

  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (e) => {
    const value = e.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <AppbarInput
      defaultDropdownItem="Purchase Order"
      id="appbar-id"
      placeholderAutoComplete="e.g. Ireland"
      dropDownData={['first', 'second', 'last']}
      autoCompleteData={state.data}
      autoCompleteValue={state.value}
      onAutoCompleteChange={onChange}
      onDropdownChange={handleOnDropdownChange}
      valid={false}
      {...args}
    />
  );
};
