import { Meta } from '@storybook/react';
import { AutoComplete } from './auto-complete';
import { filterBy } from '@progress/kendo-data-query';
import { useState } from 'react';

export default {
  component: AutoComplete,
  title: 'Dropdowns/AutoComplete',
} as Meta;

const countries = [
  'Albania',
  'Belarus',
  'Croatia',
  'Denmark',
  'Estonia',
  'Finland',
  'Georgia',
  'Hungary',
  'Ireland',
  'Kosovo',
  'Latvia',
  'Macedonia',
  'Norway',
  'Poland',
  'Romania',
  'San Marino',
  'Turkey',
  'Ukraine',
  'Vatican City',
];

export const Primary = ({ ...args }) => {
  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (e) => {
    const value = e.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <div style={{ width: '300px' }}>
      <AutoComplete
        label="Primary"
        placeholder="e.g. Ireland"
        data={state.data}
        value={state.value}
        onChange={onChange}
        {...args}
      />
    </div>
  );
};

export const Icon = ({ ...args }) => {
  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (event) => {
    const value = event.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <div style={{ width: '300px' }}>
      <AutoComplete
        label="Icon"
        placeholder="e.g. Denmark"
        data={state.data}
        value={state.value}
        icon="search"
        onChange={onChange}
        {...args}
      />
    </div>
  );
};

export const Disabled = ({ ...args }) => {
  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (event) => {
    const value = event.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <div style={{ width: '300px' }}>
      <AutoComplete
        label="Disabled"
        placeholder="e.g. Denmark"
        data={state.data}
        value={state.value}
        icon="search"
        onChange={onChange}
        disabled={true}
        {...args}
      />
    </div>
  );
};

export const Error = ({ ...args }) => {
  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (event) => {
    const value = event.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <div style={{ width: '300px' }}>
      <AutoComplete
        label="Error"
        placeholder="e.g. Denmark"
        data={state.data}
        value={state.value}
        icon="search"
        onChange={onChange}
        valid={false}
        {...args}
      />
    </div>
  );
};

export const Hint = ({ ...args }) => {
  const [state, setState] = useState({
    data: countries,
    value: '',
  });

  const filterData = (value) => {
    const data = countries;
    const filter = {
      value: value,
      operator: 'startswith',
      ignoreCase: true,
    };
    return value ? filterBy(data, filter) : data;
  };

  const onChange = (event) => {
    const value = event.value;
    setState({
      data: filterData(value),
      value: value,
    });
  };

  return (
    <div style={{ width: '300px' }}>
      <AutoComplete
        label="Hint"
        placeholder="e.g. Denmark"
        data={state.data}
        value={state.value}
        icon="search"
        onChange={onChange}
        hint="hint"
        {...args}
      />
    </div>
  );
};
