import { AutoCompleteProps as KAutoCompleteProps } from '@progress/kendo-react-dropdowns';
import { rem } from '../../utils';
import { IconNavSearch } from '../../';
import '../../theme/base-theme.scss';
import { StyledAutoComplete, StyledSearchInputContainer } from './styles';
import InputFieldWrapper from '../inputFieldWrapper/InputFieldWrapper';

/* eslint-disable-next-line */
export interface AutoCompleteProps extends Omit<KAutoCompleteProps, "size"> {
   /** display label default:inline to input field or above input field  */
   displayLabel?: 'default'|'none'|'above';
   /** for default display label, label width can be provided in px, or percentage */
   labelWidth?: string;
   /**
    * enableEditorValid:true will make label red if field is invalid
    * default false, so label will remain black in color 
    */
   enableEditorValid?:boolean;
  /** The label to display above the dropdown list. */
  label?: string;
  /** Optional icon displayed to side of input.  */
  icon?: 'search' | 'default';
  /** Sets the size of the input.  */
  hint?: string;
  /** Sets the size of the input.  */
  disabled?: boolean;
  /** Sets the size of a Input */
  size?: 'xx-small' |'x-small'| 'small'|'normal' | 'medium' | 'large' |'x-large'|'xx-large'| undefined;
   /** transient prop */
   $size?: any;
  /** todo */
  fieldWrapperProps?: {
    className?: string | undefined;
    dir?: string;
    style?: React.CSSProperties;
  };
}

export const AutoComplete = ({
  label,
  valid = true,
  disabled,
  validationMessage,
  hint,
  id = '',
  size = 'small',
  icon = 'default',
  fieldWrapperProps,
  required,
  displayLabel="above",
  labelWidth,
  enableEditorValid,
  ...props
}: AutoCompleteProps) => {
  return (
    <InputFieldWrapper
      label={label}
      size={size}
      valid = {valid}
      disabled={disabled}
      required={required}
      validationMessage={validationMessage}
      hint={hint}
      id = {id}
      displayLabel={displayLabel}
      labelWidth={labelWidth}
      enableEditorValid={enableEditorValid}
      fieldWrapperProps={fieldWrapperProps}
    >
      <StyledSearchInputContainer icon={icon}>
        {icon === 'search' && (
          <IconNavSearch fontSize={rem(25)} title="search" titleId="search" />
        )}
        <StyledAutoComplete
          valid={valid}
          $size={size}
          id={id}
          disabled={disabled}
          {...props}
        />
      </StyledSearchInputContainer>
    </InputFieldWrapper>
  );
};

export default AutoComplete;
