import { useState } from 'react';
import { Story, Meta } from '@storybook/react';
import Button, { ButtonProps } from './button';
import { colors, rem } from '../../utils';
import { IconNavFavorite, IconFilter } from '@bamboorose/br-components';

export default {
  component: Button,
  title: 'Buttons/Button',
  argTypes: {
    themeColor: {
      table: {
        disable: true,
      },
    },
    fillMode: {
      table: {
        disable: true,
      },
    },
    icon: {
      table: {
        disable: true,
      },
    },
    iconClass: {
      table: {
        disable: true,
      },
    },
    rounded: {
      table: {
        disable: true,
      },
    },
    shape: {
      table: {
        disable: true,
      },
    },
  },
} as Meta;

const Template: Story<ButtonProps> = (args) => (
  <Button {...args}>{args.children}</Button>
);

export const Primary = Template.bind({});
Primary.args = {
  variant: 'primary',
  children: 'Hello, world!',
};

export const Secondary = Template.bind({});
Secondary.args = {
  variant: 'secondary',
  children: 'Hello, world!',
};

export const FlatButton = Template.bind({});
FlatButton.args = {
  variant: 'flat',
  children: 'Hello, world!',
};

export const DarkButton = Template.bind({});
DarkButton.args = {
  variant: 'dark',
  children: 'Hello, world!',
};

export const OutlineButton = Template.bind({});
OutlineButton.args = {
  variant: 'outline',
  children: 'Hello, world!',
};

export const IconButton = Template.bind({});
IconButton.args = {
  variant: 'icon',
  children: <IconNavFavorite fontSize={rem(20)} fill={colors.white} />,
};

export const IconTextFlat = Template.bind({});
IconTextFlat.args = {
  variant: 'icon-text-flat',
  children: (
    <>
      <IconFilter
        fontSize={rem(25)}
        stroke={colors.purple}
        fill={colors.white}
      />
      <span style={{ color: '#872C8C' }}>Hide Filters</span>
    </>
  ),
};

export const Togglable = ({ ...args }) => {
  const [selected, setSelected] = useState(false);
  const handleSelected = () => setSelected(!selected);

  return (
    <Button
      variant="secondary"
      size="small"
      togglable={true}
      onClick={handleSelected}
      toggle={selected}
      {...args}
    >
      0 / 3
    </Button>
  );
};
