import styled, { css } from 'styled-components';
import { Button } from '@progress/kendo-react-buttons';
import { ButtonProps } from '../button';
import { colors, rem, fontWeights, fontSize, inputHeight } from '../../../utils';
import '../../../theme/base-theme.scss';

const StyledButton = styled(Button)<ButtonProps>`
  &&& {
    font-weight: ${fontWeights.semiBold};
    border-radius: ${rem(4)};
    span {
      align-self: center;
    }
    ${({ togglable }) =>
      togglable &&
      css`
        padding: ${rem(8)} ${rem(16)} ${rem(8)} ${rem(16)};
      `}
  }

  ${({ variant }) => {
    switch (variant) {
      case 'primary':
        return css`
          background: ${colors.mauve};
          color: ${colors.white};
          &:hover {
            background-color: ${colors.darkMauve};
          }
          &:active {
            background-color: ${colors.darkMauveOpas75};
          }
          &:disabled {
            background-color: ${colors.gray300};
            border-color: ${colors.gray300};
            opacity: 1;
          }
        `;
      case 'secondary':
        return css`
          background: ${colors.violet};
          color: ${colors.white};
          &:hover {
            background-color: ${colors.darkViolet};
            color: ${colors.white};
          }
          &:active {
            background-color: ${colors.violet};
          }
          &:disabled {
            background-color: ${colors.gray300};
            border-color: ${colors.gray300};
            opacity: 1;
          }
        `;
      case 'dark':
        return css`
          background: ${colors.gray400};
          color: ${colors.white};
          &:hover {
            background-color: ${colors.gray500};
            color: ${colors.white};
          }
          &:active {
            background-color: ${colors.gray400};
          }
          &:disabled {
            background-color: #c2c2c2;
            border-color: #c2c2c2;
            opacity: 1;
          }
        `;
      case 'outline':
        return css`
          background: ${colors.white};
          color: ${colors.gray500};
          &:hover {
            background: ${colors.white};
            border: ${rem(1)} solid ${colors.darkMauve};
            color: ${colors.darkMauve};
          }
          &:active {
            border: ${rem(1)} solid transparent;
            color: ${colors.darkMauve};
            background: ${colors.extralightIndigo};
          }
          &:disabled {
            background-color: ${colors.white};
            color: ${colors.gray400};
            border-color: ${colors.gray200};
            opacity: 0.4;
          }
        `;
      case 'flat':
        return css`
          background: transparent;
          color: ${colors.purple};
          border: none;
          &:hover {
            background-color: ${colors.white};
            color: ${colors.darkMauve};
          }
          &:active {
            color: ${colors.darkMauve};
          }
          &:disabled {
            background-color: transparent;
            opacity: 0.4;
          }
        `;
      case 'icon':
        return css`
          background: transparent;

          & span {
            display: flex;
          }
          &:hover {
            background: ${colors.white};
            border: ${rem(1)} solid ${colors.darkMauve};
            color: ${colors.darkMauve};
          }
          &:active {
            border: ${rem(1)} solid transparent;
            color: ${colors.darkMauve};
            background: ${colors.extralightIndigo};
          }
          &:disabled {
            background-color: ${colors.white};
            color: ${colors.gray400};
            border-color: ${colors.gray200};
            opacity: 0.4;
          }
        `;
      case 'icon-text-flat':
        return css`
          display: flex;
          background: ${colors.white};
          border: none;

          &:disabled {
            background-color: ${colors.white};
            color: ${colors.gray400};
            border-color: ${colors.gray200};
            opacity: 0.4;
          }

          & > span {
            display: flex;
            align-items: baseline;
            & > svg {
              margin-right: ${rem(10)};
              margin-bottom: ${rem(2)};
            }
            & > span {
              font-size: ${fontSize.medium};
            }
          }
        `;
      default:
        return css`
          background: ${colors.mauve};
          color: ${colors.white};
          &:hover {
            background-color: ${colors.darkMauve};
          }
          &:active {
            background-color: ${colors.darkMauveOpas75};
          }
          &:disabled {
            background-color: ${colors.gray300};
            border-color: ${colors.gray300};
            opacity: 1;
          }
        `;
    }
  }}

  ${({ toggle, togglable }) =>
    toggle === 'false' &&
    togglable &&
    css`
      background-color: ${colors.white};
      color: ${colors.violet};
      border: 1px solid ${colors.violet};
    `}

    ${({ toggle, togglable }) =>
    toggle === 'true' &&
    css`
      &&& {
        background-color: ${colors.violet};
        color: ${colors.white};
        border: 1px solid ${colors.violet};
        &.k-selected{
          background-color: ${colors.violet};
        }
      }
    `}


  ${({ $size }) => {
    switch ($size) {
      case 'xx-large':
        return css`
          padding: ${rem(12)} ${rem(16)};
          max-height: ${inputHeight.xxlg};
          font-size: ${fontSize.xxLarge};
          line-height: ${rem(24)};
        `;
      case 'x-large':
        return css`
          padding: ${rem(12)} ${rem(16)};
          max-height: ${inputHeight.xlg};
          font-size: ${fontSize.xLarge};
          line-height: ${rem(24)};
        `;
      case 'large':
        return css`
          padding: ${rem(12)} ${rem(16)};
          max-height: ${inputHeight.lg};
          font-size: ${fontSize.large};
          line-height: ${rem(24)};
        `;
      case 'medium':
        return css`
          &&& {
            padding: ${rem(8)} ${rem(12)};
            max-height: ${inputHeight.medium};
            font-size: ${fontSize.medium};
            line-height: ${rem(19)};
          }
        `;
      case 'normal':
        return css`
          &&& {
            padding: ${rem(8)} ${rem(12)};
            max-height: ${inputHeight.normal};
            font-size: ${fontSize.normal}
            line-height: ${rem(19)};
          }
        `;
      case 'small':
        return css`
          padding: ${rem(8)};
          max-height: ${inputHeight.sm};
          font-size: ${fontSize.small};
          line-height: ${rem(16)};
        `;
      case 'x-small':
        return css`
          padding: ${rem(8)};
          max-height: ${inputHeight.xsm};
          font-size: ${fontSize.xSmall};
          line-height: ${rem(16)};
      `;
      case 'xx-small':
        return css`
          padding: ${rem(8)};
          max-height: ${inputHeight.xxsm};
          font-size: ${fontSize.xxSmall};
          line-height: ${rem(16)};
      `;
      default:
        return css`
          &&& {
            padding: ${rem(8)} ${rem(12)};
            max-height: ${inputHeight.sm};
            font-size: ${fontSize.small};
            line-height: ${rem(19)};
          }
        `;
    }
  }}
`;

export default StyledButton;
