import { useEffect, useState, ReactElement } from 'react';
import {
  IconNavClose,
  IconWarningFilled,
  IconCheckedCircle,
  IconCloseCircle,
  IconInfoSolid,
} from '../../';
import { rem, colors } from '../../utils';
import { StyledCallout } from './styles';

/* eslint-disable-next-line */
export interface CalloutProps {
  /** todo */
  label?: string;
  /** todo */
  variant?: 'default' | 'success' | 'warning' | 'error';
  /** todo */
  onClose?: (e: any) => void;
  /** todo */
  isDismissible?: boolean;
  /** todo */
  maxWidth?: string | number;
}

export const Callout = ({
  label,
  variant = 'default',
  isDismissible = true,
  maxWidth,
  onClose,
  ...others
}: CalloutProps) => {
  const [variantType, setVariantType] = useState<ReactElement>();

  useEffect(() => {
    if (variant === 'warning') {
      setVariantType(
        <IconWarningFilled fontSize={rem(30)} fill={colors.orange} />
      );
      return;
    }
    if (variant === 'error') {
      setVariantType(<IconCloseCircle fontSize={rem(25)} fill={colors.red} />);
      return;
    }
    if (variant === 'success') {
      setVariantType(
        <IconCheckedCircle fontSize={rem(25)} fill={colors.darkGreen} />
      );
      return;
    }
    setVariantType(<IconInfoSolid fontSize={rem(35)} fill={colors.violet} />);
    return;
  }, [variant]);

  const handleOnClose = (e) => onClose?.(e);

  return (
    <StyledCallout
      onClose={onClose}
      variant={variant}
      isDismissible={isDismissible}
      maxWidth={maxWidth}
      {...others}
    >
      <div>{variantType}</div>
      <p>{label}</p>
      {isDismissible && (
        <div>
          <button type="button" onClick={handleOnClose}>
            <IconNavClose fill={colors.gray500} fontSize={rem(25)} />
          </button>
        </div>
      )}
    </StyledCallout>
  );
};

export default Callout;
