import styled, { css } from 'styled-components';
import { rem, colors, fontWeights, fontSize } from '../../../utils';
import { CalloutProps } from '../callout';

export const StyledCallout = styled.div<CalloutProps>`
  display: flex;
  align-items: center;
  background-color: #d8ccea;
  ${({ maxWidth }) =>
    maxWidth &&
    css`
      max-width: ${rem(maxWidth)};
    `}
  ${({ maxWidth }) =>
    !maxWidth &&
    css`
      width: 100%;
    `}
  
  min-height: ${rem(44)};
  border-radius: ${rem(4)};
  border: 1px solid ${colors.violet};

  & div {
    padding: ${rem(5)} ${rem(17)} 0 ${rem(17)};
  }

  & p {
    flex: 1;
    color: ${colors.gray500};
    font-weight: ${fontWeights.semiBold};
    font-size: ${fontSize.large};
    line-height: ${rem(24)};
    padding: ${rem(8)} 0;
    margin: 0;
  }

  & button {
    background-color: transparent;
    border: none;
    padding: 0;
    cursor: pointer;
  }

  ${({ variant }) => {
    switch (variant) {
      case 'success':
        return css`
          background-color: ${colors.extraLightGreen};
          border-color: ${colors.darkGreen};
        `;
      case 'warning':
        return css`
          background-color: ${colors.extraLightOrange};
          border-color: ${colors.orange};
        `;
      case 'error':
        return css`
          background-color: ${colors.extraLightRed};
          border-color: ${colors.red};
        `;
      default:
        return css`
          background-color: ${colors.lightViolet};
          border-color: ${colors.violet};
        `;
    }
  }}
`;
