import { Meta } from '@storybook/react';
import { ComboBox } from './combo-box';
import { filterBy } from '@progress/kendo-data-query';
import { useState } from 'react';

export default {
  component: ComboBox,
  title: 'Dropdowns/ComboBox',
} as Meta;

const countries = [
  'Albania',
  'Belarus',
  'Croatia',
  'Denmark',
  'Estonia',
  'Finland',
  'Georgia',
  'Hungary',
  'Ireland',
  'Kosovo',
  'Latvia',
  'Macedonia',
  'Norway',
  'Poland',
  'Romania',
  'San Marino',
  'Turkey',
  'Ukraine',
  'Vatican City',
];

export const Primary = (args) => {
  return (
    <div style={{ maxWidth: '300px' }}>
      <ComboBox label="Primary" data={countries} {...args} />
    </div>
  );
};

export const Disabled = (args) => {
  return (
    <div style={{ maxWidth: '300px' }}>
      <ComboBox label="Disabled" disabled={true} data={countries} {...args} />
    </div>
  );
};

export const Error = (args) => {
  return (
    <div style={{ maxWidth: '300px' }}>
      <ComboBox
        label="Error"
        valid={false}
        validationMessage="validation message"
        data={countries}
        {...args}
      />
    </div>
  );
};

export const Hint = (args) => {
  return (
    <div style={{ maxWidth: '300px' }}>
      <ComboBox label="Hint" hint="hint" data={countries} {...args} />
    </div>
  );
};

export const Filter = (args) => {
  const [data, setData] = useState(countries.slice());

  const filterData = (filter) => {
    const data = countries.slice();
    return filterBy(data, filter);
  };

  const filterChange = (e) => setData(filterData(e.filter));

  return (
    <div style={{ maxWidth: '300px' }}>
      <ComboBox
        label="Filter"
        data={data}
        filterable={true}
        onFilterChange={filterChange}
        {...args}
      />
    </div>
  );
};
