import { ComboBoxProps as KComboBoxProps } from '@progress/kendo-react-dropdowns';
import InputFieldWrapper from '../inputFieldWrapper/InputFieldWrapper';
import { StyledComboBox } from './styles';

/* eslint-disable-next-line */
export interface ComboBoxProps extends KComboBoxProps {
  /** display label default:inline to input field or above input field  */
  displayLabel?: 'default'|'none'|'above';
  /** for default display label, label width can be provided in px, or percentage */
  labelWidth?: string;
  /**
   * enableEditorValid:true will make label red if field is invalid
   * default false, so label will remain black in color 
   */
  enableEditorValid?:boolean;
  /** The list to be displayName in the dropdown */
  data?: any[];
  /** The label to display above the dropdown list. */
  label?: string;
  /** Sets the background color of DropDownList */
  status?: 'success' | 'warning' | 'error' | 'neutral' | undefined;
  /** transient prop */
  $hasStatus?: string;
  /** Sets the size of the input.  */
  hint?: string;
  /** todo  */
  disabled?: boolean;
  /** todo */
  fieldWrapperProps?: {
    className?: string | undefined;
    dir?: string;
    style?: React.CSSProperties;
  };
}

export const ComboBox = ({
  label,
  valid = true,
  disabled,
  validationMessage,
  hint,
  size="small",
  id = '',
  fieldWrapperProps,
  required,
  displayLabel="above",
  labelWidth,
  enableEditorValid,
  ...props
}: ComboBoxProps) => {
  const showValidationMessage = validationMessage;
  const showHint = !showValidationMessage && hint;
  const hindId = showHint ? `${id}_hint` : '';
  const errorId = showValidationMessage ? `${id}_error` : '';

  return (
    <InputFieldWrapper
      label={label}
      size={size}
      valid = {valid}
      disabled={disabled}
      required={required}
      validationMessage={validationMessage}
      hint={hint}
      id = {id}
      displayLabel={displayLabel}
      labelWidth={labelWidth}
      enableEditorValid={enableEditorValid}
      fieldWrapperProps={fieldWrapperProps}
    >
      <StyledComboBox
        size={size}
        valid={valid}
        id={id}
        disabled={disabled}
        {...props}
      />
    </InputFieldWrapper>
  );
};

export default ComboBox;
