import { createRoot } from 'react-dom/client';

export default class CustomElement extends HTMLElement {
  constructor() {
    super();
    const shadowRoot = this.attachShadow({ mode: 'open' }); //shadow root in mode: open
    const styleSlot = document.createElement('section'); // styleSlot, section to append external css/js links for shadow dom
    shadowRoot.appendChild(styleSlot);
    const shadowRootContent = document.createElement('div'); //container to load content
    shadowRootContent.id = 'shadowRootContent';
    styleSlot.appendChild(shadowRootContent);
  }

  connectedCallback() {
    //connected callback
  }
  disconnectedCallback() {
    // browser calls this method when the element is removed from the document
    // (can be called many times if an element is repeatedly added/removed)
  }

  static get observedAttributes() {
    return ['name'];
  }

  attributeChangedCallback(name, oldValue, newValue) {
    console.log('attribute changed', name, oldValue, newValue);
    if (name === 'component') {
      console.log('component', name, oldValue, newValue);
      this._params = { ...this._params, component: newValue };
      this.render();
    }
    // called when one of attributes listed above is modified
  }

  adoptedCallback() {
    // called when the element is moved to a new document
    // (happens in document.adoptNode, very rarely used)
  }

  // there can be other element methods and properties
  get params() {
    return this._params || {};
  }
  set params(obj) {
    this._params = obj || {};
    this.render();
  }
  render() {
    const params = this._params;
    const { head, story: Story, context } = params;
    const shadowRoot = this.shadowRoot;
    const styleSlot = shadowRoot.querySelector('section');
    const container = shadowRoot.getElementById('shadowRootContent');
    styleSlot.prepend(head);
    const root = createRoot(container);
    root.render(<Story {...context} />);
  }
}
