import React from 'react';
import {
  Chart as KChart,
  ChartLegend as KChartLegend,
  ChartSeries as KChartSeries,
  ChartSeriesItem as KChartSeriesItem,
  ChartProps as KChartProps,
  ChartArea as KChartArea,
} from '@progress/kendo-react-charts';
import { StyledDonutChartGroup, StyledChartContainer } from './styles';
import '../../theme/base-theme.scss';

export interface Data {
  /** todo */
  kind: string;
  /** todo */
  share: number;
}

export interface DonutChartGroupProps extends KChartProps {
  /** Primary value of the chart */
  value: number | string;
  /** The title describing the chart */
  title: string;
  /** The data that generates the chart */
  data?: Data[];
}

export const DonutChartGroup = ({
  value,
  title,
  data,
  ...props
}: DonutChartGroupProps) => {
  props = {
    ...props,
    seriesColors: [
      '#6332ac',
      '#e31d3c',
      '#f2b919',
      '#d31999',
      '#4da300',
      '#ff5892',
    ],
  };

  return (
    <StyledDonutChartGroup>
      <>
        <div>
          <span>{value}</span>
          <span>{title}</span>
        </div>
        {data && (
          <StyledChartContainer>
            <KChart {...props}>
              <KChartArea
                background="transparent"
                margin={0}
                width={80}
                height={80}
              />
              <KChartSeries>
                <KChartSeriesItem
                  type="donut"
                  data={data}
                  categoryField="kind"
                  field="share"
                ></KChartSeriesItem>
              </KChartSeries>
              <KChartLegend visible={false} />
            </KChart>
          </StyledChartContainer>
        )}
      </>
    </StyledDonutChartGroup>
  );
};

export default React.memo(DonutChartGroup);
