import { Meta } from '@storybook/react';
import { Drawer } from './drawer';
import { Button, Collapse, LinkList, ColorSwatch } from '../../';
import styled from 'styled-components';
import { useState } from 'react';

export default {
  component: Drawer,
  title: 'Layout/Drawer',
} as Meta;

const StyledContainer = styled.div`
  display: flex;
  flex-direction: column;
`;

const StyledHeader = styled.header`
  width: 99%;
  height: 50px;
  background-color: lightgray;
  display: flex;
  padding: 5px;
  align-items: center;
`;

const StyledMain = styled.main`
  width: 100%;
  height: 100vh;
  margin-top: 10px;
  background-color: lightgray;
`;

const StyledUL = styled.ul`
  list-style: none;
  margin: 0;
  padding: 0;

  & > li:not(:last-of-type) {
    margin-bottom: 20px;
  }
`;

export const Primary = (args) => {
  const [toggleDrawer, setToggleDrawer] = useState(false);

  const handleToggleDrawer = () => setToggleDrawer(!toggleDrawer);

  return (
    <StyledContainer>
      <Drawer attachTo="root" isActive={toggleDrawer} {...args}>
        <></>
      </Drawer>
      <StyledHeader>
        <Button type="button" onClick={handleToggleDrawer}>
          {toggleDrawer ? 'close' : 'open'}
        </Button>
      </StyledHeader>
      <StyledMain></StyledMain>
    </StyledContainer>
  );
};

export const WithChildren = (args) => {
  const [toggleDrawer, setToggleDrawer] = useState(true);

  const handleToggleDrawer = () => setToggleDrawer(!toggleDrawer);

  return (
    <StyledContainer>
      <Drawer attachTo="root" isActive={toggleDrawer} {...args}>
        <Collapse isActive={true} label="DESIGN CENTER">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse isActive={true} label="Colors">
          <StyledUL>
            <li>
              <ColorSwatch title="Color Swatch Link" color="#E31D3C" />
            </li>
            <li>
              <ColorSwatch title="Color Swatch Link" color="#F2B919" />
            </li>
            <li>
              <ColorSwatch title="Color Swatch Link" color="#422DC7" />
            </li>
            <li>
              <ColorSwatch title="Color Swatch Link" color="#80EAE9" />
            </li>
          </StyledUL>
        </Collapse>
        <Collapse label="CALENDAR">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse label="ORDER MANAGEMENT">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse label="VENDOR MANAGEMENT">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse label="OMNI-MARKET">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse label="SEARCH">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
        <Collapse label="ADMIN">
          <LinkList category="MATERIAL">
            <LinkList.Link href="#" label="Material Projections" />
            <LinkList.Link href="#" label="Material Quote" />
            <LinkList.Link href="#" label="Artwork Library" />
            <LinkList.Link href="#" label="Material Projections Summary" />
            <LinkList.Link href="#" label="Material Inventory" />
          </LinkList>
        </Collapse>
      </Drawer>
      <StyledHeader>
        <Button type="button" onClick={handleToggleDrawer}>
          {toggleDrawer ? 'close' : 'open'}
        </Button>
      </StyledHeader>
      <StyledMain></StyledMain>
    </StyledContainer>
  );
};
