import { useState } from 'react';
import { Meta } from '@storybook/react';
import { DropDownList, DropDownListProps } from './drop-down-list';

export default {
  component: DropDownList,
  title: 'Dropdowns/DropDownList',
  argTypes: {
    $hasStatus: {
      table: {
        disable: true,
      },
    },
  },
} as Meta;

export const Primary = ({ ...args }: DropDownListProps) => {
  return (
    <div style={{ width: '300px' }}>
      <DropDownList
        {...args}
        label="Primary"
        data={['first', 'second', 'last']}
      />
    </div>
  );
};

export const Error = ({ ...args }: DropDownListProps) => {
  return (
    <div style={{ width: '300px' }}>
      <DropDownList
        {...args}
        label="Error"
        data={['first', 'second', 'last']}
        validationMessage="Validation Message"
        valid={false}
      />
    </div>
  );
};

export const Hint = ({ ...args }: DropDownListProps) => {
  return (
    <div style={{ width: '300px' }}>
      <DropDownList
        {...args}
        hint="Hint"
        label="hint"
        data={['first', 'second', 'last']}
      />
    </div>
  );
};

export const Status = ({ ...args }: DropDownListProps) => {
  const [status, setStatus] = useState(args.status);
  const handleChange = (e) => setStatus(e.target.value);

  return (
    <div style={{ width: '300px' }}>
      <DropDownList
        {...args}
        onChange={handleChange}
        status={status}
        label="Status"
        data={['success', 'error', 'warning', 'neutral']}
      />
    </div>
  );
};

export const Disabled = ({ ...args }: DropDownListProps) => {
  return (
    <div style={{ width: '300px' }}>
      <DropDownList
        {...args}
        label="Disabled"
        data={['first', 'second', 'last']}
        disabled={true}
      />
    </div>
  );
};
