import { DropDownListProps as KDropDownListProps } from '@progress/kendo-react-dropdowns';
import InputFieldWrapper from '../inputFieldWrapper/InputFieldWrapper';
import { StyledDropDownList } from './styles';

export interface DropDownListProps extends KDropDownListProps {
  /** display label default:inline to input field or above input field  */
  displayLabel?: 'default'|'none'|'above';
  /** for default display label, label width can be provided in px, or percentage */
  labelWidth?: string;
  /**
   * enableEditorValid:true will make label red if field is invalid
   * default false, so label will remain black in color 
   */
  enableEditorValid?:boolean;
  /** The list to be displayName in the dropdown */
  data?: any[];
  /** The label to display above the dropdown list. */
  label?: string;
  /** Sets the background color of DropDownList */
  status?: 'success' | 'warning' | 'error' | 'neutral' | undefined;
  /** transient prop */
  $hasStatus?: string;
  /** Sets the size of the input.  */
  hint?: string;
  /** todo  */
  disabled?: boolean;
  /** todo */
  fieldWrapperProps?: {
    className?: string | undefined;
    dir?: string;
    style?: React.CSSProperties;
  };
}

export const DropDownList = ({
  label,
  status,
  valid = true,
  disabled,
  validationMessage,
  hint,
  id = '',
  size = 'small',
  displayLabel="above",
  labelWidth,
  enableEditorValid=false,
  fieldWrapperProps,
  required,
  ...props
}: DropDownListProps) => {
  return (
    <InputFieldWrapper
      label={label}
      size={size}
      valid = {valid}
      disabled={disabled}
      required={required}
      validationMessage={validationMessage}
      hint={hint}
      id = {id}
      displayLabel={displayLabel}
      labelWidth={labelWidth}
      enableEditorValid={enableEditorValid}
      fieldWrapperProps={fieldWrapperProps}
    >
      <StyledDropDownList
        valid={valid}
        id={id}
        disabled={disabled}
        $hasStatus={status}
        size={size}
        {...props}
      />
    </InputFieldWrapper> 
  );
};

export default DropDownList;
