import styled, { css } from 'styled-components';
import { DropDownList as KDropDownList } from '@progress/kendo-react-dropdowns';
import {
  colors,
  rem,
  opacity,
  inputHeight,
  fontWeights,
  fontSize,
} from '../../../utils';
import { DropDownListProps } from '../drop-down-list';

export const StyledDropDownList = styled(KDropDownList)<DropDownListProps>`
  &&& {
    color: ${colors.gray500};
    background-image: none;
    font-size: ${fontSize.large};
    font-weight: ${fontWeights.regular};
    padding: ${rem(12)} ${rem(10)};
    border: ${({ valid }) =>
      valid
        ? `${rem(1)} solid ${colors.gray250}`
        : `${rem(1)} solid ${colors.red}`};

    &:focus-within {
      border: 1px solid ${colors.purple};
      box-shadow: 0 0 0 4px
        ${({ valid }) =>
          valid ? 'rgba(135, 44, 140, 0.25)' : opacity(colors.darkRed, 0.25)};
    }

    &:hover {
      border: 1px solid ${colors.gray300};
    }

    button > span {
      font-size: ${rem(24)};
    }

    & > span {
      padding: 0;
    }

    ${({ $hasStatus }) => {
      switch ($hasStatus) {
        case 'neutral':
          return css`
            background-color: ${colors.gray200};
          `;
        case 'success':
          return css`
            background-color: ${colors.extraLightGreen};
          `;
        case 'warning':
          return css`
            background-color: ${colors.extraLightYellow};
          `;
        case 'error':
          return css`
            background-color: ${colors.extraLightRed};
          `;
        default:
          return css`
            background-color: ${colors.white};
          `;
      }
    }}

    ${({ size }) => {
      switch (size) {
        case 'small':
          return css`
            height: ${inputHeight.sm};
            padding: ${rem(4)} ${rem(2)} ${rem(4)} ${rem(10)};
            & span > span {
              font-size: ${fontSize.small};
            }
            span.k-icon.k-i-arrow-s{
              font-size: 18px;
            }
          `;
        case 'medium':
          return css`
            height: ${inputHeight.md};
            padding:  ${rem(4)} ${rem(2)} ${rem(4)} ${rem(10)};
            & span > span {
              font-size: ${fontSize.medium};
            }
            span.k-icon.k-i-arrow-s{
              font-size: 20px;
            }
          `;
        case 'large':
          return css`
            height: ${inputHeight.lg};
            padding: ${rem(4)} ${rem(2)} ${rem(4)} ${rem(10)};
            & span > span {
              font-size: ${fontSize.large};
            }
            span.k-icon.k-i-arrow-s{
              font-size: 22px;
            }
          `;
        default:
          return css`
            height: ${inputHeight.md};
            padding: ${rem(4)} ${rem(2)} ${rem(4)} ${rem(10)};
            & span > span {
              font-size: ${fontSize.large};
            }
            span.k-icon.k-i-arrow-s{
              font-size: 22px;
            }
          `;
      }
    }}

    ${({ disabled }) =>
      disabled &&
      css`
        background-color: ${colors.disabledBackground};
        border-color: ${colors.gray300};
      `}
  }
`;
