import styled from 'styled-components';
import { rem } from '../../utils';

/* eslint-disable-next-line */
export interface IconTextProps {
  /** Sets the icon components  */
  icon?: React.ReactNode;
  /** Sets the label value  */
  label?: string;
  /** Sets the text as lowercase  */
  isLowercase?: boolean;
  /** Sets the text as capitalize  */
  isCapitalize?: boolean;
}

const StyledIconTextContainer = styled.div<IconTextProps>`
  display: inline-flex;
  align-items: center;
  gap: ${rem(7)};

  & > div:last-of-type {
    text-transform: ${({ isLowercase, isCapitalize }) =>
      isLowercase ? 'lowercase' : isCapitalize ? 'capitalize' : 'uppercase'};
  }
`;

export const IconText = ({
  icon,
  label,
  isLowercase = false,
  isCapitalize = false,
  ...props
}: IconTextProps) => {
  return (
    <StyledIconTextContainer
      isCapitalize={isCapitalize}
      isLowercase={isLowercase}
      {...props}
    >
      {icon}
      {label && <div>{label}</div>}
    </StyledIconTextContainer>
  );
};

export default IconText;
