import {useEffect, useState} from 'react';
import { Meta } from '@storybook/react';
import { IconList, IconsProps } from './icon-list';
import styled from 'styled-components';
import { rem, fontSize } from '../../utils';
import { IconCloseCircle, IconWarningHand } from './components';
import {Input,Button} from '@bamboorose/br-components';
const StyleDiv = styled.div`
  display: flex;
  flex-wrap: wrap;
  font-size: 50px;
`;

const StyledContainer = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  padding: ${rem(20)};
`;

const StyledTitle = styled.div`
  font-size: 16px;
  margin-top: ${rem(14)};
`;

export default {
  title: 'Icons/Icons',
  argTypes: {
    fill: {
      control: 'text',
      description: 'Sets the fill color of an Icon',
    },
    size: {
      control: 'number',
      description: 'Sets the size of an Icon in px',
    },
    stroke: {
      control: 'text',
      description: 'Sets the stroke color of an Icon',
    },
  },
} as Meta;

export const Primary = ({ ...args }: IconsProps) => {
  const list = IconList(args);
  const [iconList,setIconList] = useState<IconsProps[]>(list);
  const [text,setText] = useState("")
  function filterIcon(event: object){
    let str = event?.value?.toLowerCase()||"";
    setText(str);
    const l = list.filter(i => i.title.toLowerCase().indexOf(str) !== -1)
    setIconList(l);
  }
  function resetIconList(){
    setText("");
    setIconList(list);
  }
  return (
    <>
      <div style={{maxWidth: "100%",display:"flex",alignItems:"end",position:"sticky",top:0,background:"#fff",paddingBottom:"15px"}}>
      <div style={{maxWidth: "400px",flex:1,marginRight:"15px"}}>
        <Input label="Filter Icon" type="text" placeholder="Filter Icon" clearable value={text} onChange={filterIcon}/>
      </div>
        <Button onClick={resetIconList}>Clear</Button>
      </div>
      <StyleDiv>
        {iconList.map(({ component:Component, title="" }) => (
          <StyledContainer key={title}>
            <div style={{background:title.indexOf("Inverse")>=0?"black":""}}>
              <Component {...args}/>
            </div>
            <StyledTitle>{title}</StyledTitle>
          </StyledContainer>
        ))}
      </StyleDiv>
    </>
  );
};

export const Size = (args: IconsProps) => {
  return (
    <StyledContainer>
      <IconCloseCircle fontSize={`100px`} />
      <IconCloseCircle fontSize={`75px`} />
      <IconCloseCircle fontSize={`50px`} />
      <IconCloseCircle fontSize={`30px`} />
    </StyledContainer>
  );
};

export const Fill = (args: IconsProps) => {
  return (
    <StyledContainer>
      <IconCloseCircle fontSize={'50px'} fill={'red'} />
      <IconCloseCircle fontSize={'50px'} fill={'green'} />
      <IconCloseCircle fontSize={'50px'} fill={'blue'} />
      <IconCloseCircle fontSize={'50px'} fill={'pink'} />
    </StyledContainer>
  );
};

export const Stroke = () => {
  return (
    <StyledContainer>
      <IconWarningHand fontSize={'50px'} stroke={'red'} />
      <IconWarningHand fontSize={'50px'} stroke={'green'} />
      <IconWarningHand fontSize={'50px'} stroke={'blue'} />
      <IconWarningHand fontSize={'50px'} stroke={'pink'} />
    </StyledContainer>
  );
};
