import { Tile } from '../../';
import { uuid } from '../../utils';
import { Pill, Popover } from '../../';
import {
  StyledProductHeader,
  StyledInfo,
  StyledInfoPanelProduct,
  StyledTitle,
} from './styles';

/* eslint-disable-next-line */
export interface InfoPanelProductProps {
  /** Adds component content/data  */
  data?:
    | {
        image: string;
        alt: string;
        title: string;
        info: { name: string | number; value: string | number }[] | undefined;
      }
    | undefined;
  /** Adds component onClick event  */
  onClick?: (e: any) => void;
  /** Add component id  */
  id?: string;
  /** todo */
  isActive?: boolean;
  /** todo */
  pillLable?: string;
  /** todo */
  pillVariant?: 'warning' | 'primary' | 'success' | 'error' | undefined;
  /** todo */
  popoverContent?: React.ReactNode;
}

export const InfoPanelProduct = ({
  data,
  onClick,
  id,
  isActive = false,
  pillLable = '',
  pillVariant,
  popoverContent,
  ...others
}: InfoPanelProductProps) => {
  const { image, alt, title, info } = data!;

  const handleOnClick = (e) => onClick?.(e);

  return (
    <StyledInfoPanelProduct
      isActive={isActive}
      id={id || `info-panel_${uuid()}`}
      {...others}
    >
      <Tile>
        <StyledProductHeader>
          <Pill label={pillLable} variant={pillVariant} />
          <Popover popoverContent={popoverContent} position="left" />
        </StyledProductHeader>
        <Tile.Body>
          {image && <img src={image} alt={alt || 'product image'} />}
        </Tile.Body>
        <Tile.Footer>
          <StyledTitle>
            <button type="button" onClick={handleOnClick}>
              {title}
            </button>
          </StyledTitle>
          {info &&
            info.map(({ name, value }) => (
              <StyledInfo key={uuid()}>
                <div>{name}:</div>
                <div>{value}</div>
              </StyledInfo>
            ))}
        </Tile.Footer>
      </Tile>
    </StyledInfoPanelProduct>
  );
};

export default InfoPanelProduct;
