import { Tile, Pill, WarningIconList, Popover, ProgressBar } from '../../';
import {
  StyledInfoPanelVendor,
  StyledHeader,
  StyledBody,
  StyledFooter,
} from './styles';
import { PopoverPosition } from '@progress/kendo-react-tooltip';
import { uuid } from '../../utils';

/* eslint-disable-next-line */
export interface InfoPanelVendorProps {
  /** Sets the Pill component label */
  pillLabel?: string;
  /** An array of warning items */
  warningItems?: string[];
  /** Sets popoverPosition to 'top' | 'bottom ' | 'left' | 'right'  */
  popoverPosition?: 'top' | 'bottom' | 'left' | 'right' | PopoverPosition;
  /** Sets the Pill component vaiant */
  pillVariant?: 'primary' | 'success' | 'warning' | 'error';
  /** Sets the content within the popover pop out container */
  popoverContent?: React.ReactNode;
  /** Set the vendors name */
  vendorName?: string;
  /** Sets the vendor number */
  vendorNumber?: string | number;
  /** Sets the vendor cost */
  vendorCost?: string | number;
  /** Sets the vendor date */
  vendorDate?: string | number | any;
  /** Sets the ProgressBar component variant */
  progressVariant?: 'success' | 'error' | 'warning';
  /** Sets the ProgressBar component value */
  progressBarValue?: number | null;
  /** Sets the card footer content */
  footerChildren?: React.ReactNode;
  /** todo */
  factoryName?: string | number;
  /** todo */
  vendorQty?: string | number;
  /** todo */
  isActive?: boolean;
  /** todo */
  id?: string;
}

export const InfoPanelVendor = ({
  pillLabel = '',
  warningItems = [],
  popoverPosition,
  pillVariant = 'primary',
  popoverContent,
  vendorName,
  vendorNumber,
  vendorCost,
  vendorDate,
  progressVariant,
  progressBarValue,
  footerChildren,
  factoryName,
  vendorQty,
  isActive = false,
  id = '',
  ...others
}: InfoPanelVendorProps) => {
  return (
    <StyledInfoPanelVendor
      id={id || `info-panel_${uuid()}`}
      isActive={isActive}
      {...others}
    >
      <Tile>
        <Tile.Body>
          <StyledHeader>
            <span>
              <Pill label={pillLabel} variant={pillVariant} />
            </span>
            <WarningIconList warningItems={warningItems} />
            <Popover
              position={popoverPosition}
              popoverContent={popoverContent}
              iconSize={20}
            />
          </StyledHeader>
          <StyledBody>
            {/* todo: find out if this should be a button */}
            <div>
              <div>{vendorName}</div>
              <div>{vendorNumber}</div>
            </div>
            <div>
              <div>{factoryName}</div>
              <div>{vendorDate}</div>
            </div>
            <div>
              <div>{`$${vendorCost}`}</div>
              <div>{`QTY ${vendorQty || '0'}`}</div>
            </div>
            <span>
              <ProgressBar
                variant={progressVariant}
                labelVisible={false}
                value={progressBarValue}
                animation={true}
              />
            </span>
          </StyledBody>
          {footerChildren && <StyledFooter>{footerChildren}</StyledFooter>}
        </Tile.Body>
      </Tile>
    </StyledInfoPanelVendor>
  );
};

export default InfoPanelVendor;
