import { FieldWrapper } from '@progress/kendo-react-form';
import { ReactElement } from 'react';
import styled from 'styled-components';
import { Label, Hint, Error } from '../..';
import { colors } from '../../utils/colors';
const StyledRequired = styled.span.attrs((props: {valid: boolean}) => props)`
    color: ${(props)=>!props.valid?colors.red:'inherit'}
`
export interface InputFieldWrapperProps {
  /** display label default:inline to input field or above input field  */
  displayLabel?: 'default'|'none'|'above';
  /** for default display label, label width can be provided in px, or percentage */
  /** defines if input field is clearable
   * if true, will show x in right corner
   * onclick will clear input field
   */
  clearable?: boolean;
  labelWidth?: string;
  /**
   * enableEditorValid:true will make label red if field is invalid
   * default false, so label will remain black in color 
   */
  enableEditorValid?:boolean;
  /** The list to be displayName in the dropdown */
  valid?: boolean;
  /** The label to display above the dropdown list. */
  label?: string;
  /** Sets the validation message */
  validationMessage?: string;
  /**id */
  id?:string;
  /** Sets the size of a Input */
  size ?: 'xx-small' |'x-small'| 'small'|'normal' | 'medium' | 'large' |'x-large'|'xx-large'| undefined|any,
  /** Sets the size of the input.  */
  hint?: string;
  /** todo  */
  disabled?: boolean;
  hidden?:boolean;
  /** required field, boolean, default false */
  required?:boolean;
  /** todo */
  fieldWrapperProps?: {
    className?: string | undefined;
    dir?: string;
    style?: React.CSSProperties;
  };
  children?: ReactElement
}

export const InputFieldWrapper = ({
  label,
  valid = true,
  disabled,
  validationMessage,
  hint,
  id = '',
  size = 'small',
  displayLabel="above",
  labelWidth,
  enableEditorValid=false,
  fieldWrapperProps,
  required,
  hidden,
  children
}: InputFieldWrapperProps) => {
  const showValidationMessage = validationMessage;
  const showHint = !showValidationMessage && hint;
  const hindId = showHint ? `${id}_hint` : '';
  const errorId = showValidationMessage ? `${id}_error` : '';
  const style = fieldWrapperProps?.style ||{};
  const labelStyle = {width:labelWidth} as any;
  if(displayLabel==='none'){
   labelStyle.display = "none";
  }else if (displayLabel==="above"){
    style.display = hidden?"none":"block";  
    labelStyle.display = "inline-block";
    labelStyle.marginBottom = "5px";
  }else{
    style.display = hidden?"none":'flex';
    style.alignItems = "baseline";
    labelStyle.marginRight = "10px";
    labelStyle.marginBottom = 0;
    labelStyle.hyphens= "auto";
  }
  return (
    <FieldWrapper
      className={fieldWrapperProps?.className}
      dir={fieldWrapperProps?.dir}
      style={style}
    >
      {label && (
        <Label
          size={size}
          editorId={id}
          editorValid={enableEditorValid? valid:true}
          editorDisabled={disabled}
          style={labelStyle}
        >
            {required && <StyledRequired valid={valid} className="required-indicator">*&nbsp;</StyledRequired>}
          {label}
        </Label>
      )}
      <>
        {children}
        {showHint && <Hint id={hindId}>{hint}</Hint>}
        {showValidationMessage && <Error id={errorId}>{validationMessage}</Error>}
      </>
    </FieldWrapper>
  );
};

export default InputFieldWrapper;
