import styled, { css } from 'styled-components';
import { colors } from '../../utils';

/* eslint-disable-next-line */
export interface LinkProps {
  /**
   * href attribute
   * link url to navigate to
   */
  href?: string;
  /**
   * target attribute
   * - `_blank`	Opens the linked document in a new window or tab
   * - `_self`	Opens the linked document in the same frame as it was clicked (this is default)
   * - `_parent`	Opens the linked document in the parent frame
   * - `_top	Opens` the linked document in the full body of the window
   * - `framename`	Opens the linked document in the named iframe
   */
  target?: "_blank"|"_self"|"_parent"|"_top"|"framename";
  /**
   * style attribute
   * custom inline style attribute
   */
  style?: React.CSSProperties | any;
  children?: React.ReactNode;
  /**
   * textDecoration prop
   * `"underline" | "overline" |"dashed underline" | "none" | string`
   */
  textDecoration?: "underline" | "overline" |"dashed underline" | "none" | string;
  /**
   * 
   */
  disabled?: boolean;
  onClick?: ((event: any) => undefined) | undefined;
}
interface AnchorProps {
  textDecoration?: string;
  disabled?: boolean;
  children?: React.ReactNode;
}
const StyledLink = styled("a")<AnchorProps>`
  color: ${colors.purple};
  ${({textDecoration})=>css`
    text-decoration: ${textDecoration || 'none'};
  `}
  ${({disabled})=> disabled && css`
    color: ${colors.disabledText};
    text-decoration: none;
    pointer-events: none;
    cursor: not-allowed;
  `}
`;

export function Link({
  children,
  disabled,
  onClick=()=>undefined,
  ...props}: LinkProps) {
  function handleClick(event: any){
    !disabled && onClick(event);
    return;
  }
  return (
    <StyledLink {...props} disabled={disabled} onClick={handleClick}>
      {children}
    </StyledLink>
  );
}

export default Link;
