import styled from 'styled-components';
import { Story, Meta } from '@storybook/react';
import { useState } from 'react';
import { Modal, ModalProps } from './modal';
import {
  IconCheckedOutline,
  ToggleButtonGroup,
  Button,
  IconWarning,
  IconAlertOutlineLarge,
} from '../../';
import { rem } from '../../utils';

export default {
  component: Modal,
  title: 'Dialogs/Modal',
} as Meta;

const StyledContainer = styled.div`
  display: flex;
  align-items: center;
  justify-content: flex-start;
  width: 100%;
`;

const StyledTitle = styled.div`
  display: flex;
  margin-left: ${rem(10)};
  font-size: ${rem(16)};
  display: inline-block;
  flex: 1;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
`;

const StyledButtons = styled.div`
  display: flex;
  margin-right: ${rem(20)};
`;

const Template: Story<ModalProps> = (args) => {
  const [visible, setVisible] = useState<boolean>(false);

  const toggleModal = () => {
    setVisible(!visible);
  };

  const ButtonsDemoComponent = () => {
    return (
      <>
        <Button onClick={toggleModal} variant="outline">
          Cancel
        </Button>
        <Button onClick={toggleModal} variant="primary">
          Submit
        </Button>
      </>
    );
  };

  return (
    <>
      <Button onClick={toggleModal}>Toggle Window</Button>
      {visible && (
        <Modal
          title="Some really long title that should be truncated"
          onClose={toggleModal}
          actionBarContent={<ButtonsDemoComponent />}
          {...args}
        >
          <div>
            <p>
              Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris eu
              nunc eget nunc ornare aliquam.
            </p>
          </div>
        </Modal>
      )}
    </>
  );
};

export const Window = Template.bind({});
Window.args = {};

const TitleComponent = () => {
  return (
    <StyledContainer>
      <StyledTitle>Claim</StyledTitle>
      <ToggleButtonGroup
        iconColor="white"
        iconType="secondary"
        hasBorder={false}
        onClick={() => {}}
      />
    </StyledContainer>
  );
};

export const CustomHeader = Template.bind({});
CustomHeader.args = {
  title: <TitleComponent />,
};

export const Resize = Template.bind({});
Resize.args = {
  title: 'Resize me',
  resizable: true,
};

export const WidthAndHeight = Template.bind({});
WidthAndHeight.args = {
  initialHeight: 200,
  initialWidth: 750,
};

export const WidthAndHeightPercentage = Template.bind({});
WidthAndHeightPercentage.args = {
  percentageWidth: 50,
  percentageHeight: 50,
  percentageLeft: 20,
};

export const AsAModal = Template.bind({});
AsAModal.args = {
  modal: true,
};

export const Primary = Template.bind({});
Primary.args = {
  variant: 'primary',
};

export const Secondary = Template.bind({});
Secondary.args = {
  variant: 'secondary',
};

const ButtonsDarkDemoComponent = () => {
  return (
    <>
      <Button variant="outline">Cancel</Button>
      <Button variant="dark">Submit</Button>
    </>
  );
};

const TitleSuccess = () => {
  return (
    <StyledContainer>
      <IconCheckedOutline fontSize="24px" stroke="white" />
      <StyledTitle>Success</StyledTitle>
    </StyledContainer>
  );
};

export const Success = Template.bind({});
Success.args = {
  variant: 'success',
  title: <TitleSuccess />,
  actionBarContent: <ButtonsDarkDemoComponent />,
};

const TitleWarning = () => {
  return (
    <StyledContainer>
      <IconWarning fontSize="30px" stroke="white" fill="white" />
      <StyledTitle>Warning</StyledTitle>
    </StyledContainer>
  );
};

export const Warning = Template.bind({});
Warning.args = {
  variant: 'warning',
  title: <TitleWarning />,
  actionBarContent: <ButtonsDarkDemoComponent />,
};

const TitleError = () => {
  return (
    <StyledContainer>
      <IconAlertOutlineLarge fontSize="30px" stroke="white" fill="white" />
      <StyledTitle>Error</StyledTitle>
    </StyledContainer>
  );
};

export const Error = Template.bind({});
Error.args = {
  variant: 'error',
  title: <TitleError />,
  actionBarContent: <ButtonsDarkDemoComponent />,
};
