import styled, { css } from 'styled-components';
import { Window } from '@progress/kendo-react-dialogs';
import { colors, rem } from '../../../utils';
import { ModalProps } from '../modal';

export const StyledModal = styled(Window)<ModalProps>`
  box-shadow: 1px 1px 7px 1px rgb(0 0 0 / 30%);
  border-radius: ${rem(4)};
  min-width:200px;
  min-height:150px;
  .k-window-titlebar {
    ${({ variant }) => {
      switch (variant) {
        case 'primary':
          return css`
            background-color: ${colors.mauve};
          `;
        case 'secondary':
          return css`
            background-color: ${colors.purple};
          `;
        case 'success':
          return css`
            background-color: ${colors.green};
          `;
        case 'warning':
          return css`
            background-color: ${colors.orange};
          `;
        case 'error':
          return css`
            background-color: ${colors.red};
          `;
        default:
          return css`
            background-color: ${colors.mauve};
          `;
      }
    }}
    color: ${colors.white};
    border-top-left-radius: ${rem(4)};
    border-top-right-radius: ${rem(4)};

    .k-window-title {
      display: inline-block;
      flex: 1;
      white-space: nowrap;
      overflow: hidden;
      text-overflow: ellipsis;
      &:before{
        content:none;
      }
    }
  }
  .k-window-content {
    background-color: ${colors.white};
    border-radius: ${rem(4)};
    ${({ contentPadding }) => { return css`padding:${contentPadding}px;`}}
  }

  .k-actions {
    background-color: ${colors.disabledBackground};
    border-bottom-left-radius: ${rem(4)};
    border-bottom-right-radius: ${rem(4)};
    border: none;
    padding:10px 20px;
    gap:20px;
  }

  &&& {
    .has-action-bar .k-window-content {
      border-bottom-left-radius: ${rem(0)};
      border-bottom-right-radius: ${rem(0)};
    }
  }
`;
