import { Story, Meta } from '@storybook/react';
import { useState } from 'react';
import { MultiSelectDropdown, MultiSelectProps } from './multi-select-dropdown';

const data = ['first', 'second', 'last'];

export default {
  component: MultiSelectDropdown,
  title: 'Dropdowns/MultiSelectDropdown',
  argTypes: {
    $hasSize: {
      table: {
        disable: true,
      },
    },
    size: {
      control: 'radio',
      options: ['xx-small','x-small','small','normal', 'medium', 'large','x-large','xx-large']
    },
  },
} as Meta;

const Template: Story<MultiSelectProps> = (args) => (
  <div style={{ width: '300px' }}>
    <MultiSelectDropdown {...args} />
  </div>
);

export const Primary = ({ ...args }) => {
  const [value, setValue] = useState([]);

  const onChange = (event) => {
    setValue([...event.value]);
  };

  console.log(value);

  return (
    <>
      <div style={{ width: '300px', marginBottom: '30px' }}>
        <MultiSelectDropdown
          data={data}
          label="Primary"
          onChange={onChange}
          value={value}
          {...args}
        />
      </div>
      <div style={{ marginBottom: '10px' }}>output</div>
      {value.map((v) => (
        <span style={{ marginRight: '20px', color: 'red' }}>{v}</span>
      ))}
    </>
  );
};

export const Error = Template.bind({});
Error.args = {
  label: 'Error',
  validationMessage: 'Validation Message',
  data,
  valid: false,
};

export const Hint = Template.bind({});
Hint.args = {
  label: 'Hint',
  hint: 'hint',
  data,
};

export const Disabled = Template.bind({});
Disabled.args = {
  label: 'Disabled',
  disabled: true,
  data,
};
