import { MultiSelectProps as KMultiSelectProps } from '@progress/kendo-react-dropdowns';
import { FieldWrapper } from '@progress/kendo-react-form';
import { Label, Hint, Error } from '../../';
import '../../theme/base-theme.scss';
import InputFieldWrapper from '../inputFieldWrapper/InputFieldWrapper';
import { StyledMultiSelectDropdown } from './styles';

/* eslint-disable-next-line */
export interface MultiSelectProps extends Omit<KMultiSelectProps,"size"> {
  /** display label default:inline to input field or above input field  */
  displayLabel?: 'default'|'none'|'above';
  /** for default display label, label width can be provided in px, or percentage */
  labelWidth?: string;
  /**
   * enableEditorValid:true will make label red if field is invalid
   * default false, so label will remain black in color 
   */
  enableEditorValid?:boolean;
  /** Sets the size of a Input */
  size?: 'xx-small' |'x-small'| 'small'|'normal' | 'medium' | 'large' |'x-large'|'xx-large'| undefined,
  /** Sets the size of the input.  */
  hint?: string;
  /** transient prop */
  $hasSize?: any;
  /** todo */
  fieldWrapperProps?: {
    className?: string | undefined;
    dir?: string;
    style?: React.CSSProperties;
  };
}

export const MultiSelectDropdown = ({
  size = 'small',
  valid = true,
  label,
  id,
  disabled,
  validationMessage,
  hint,
  fieldWrapperProps,
  required,
  displayLabel="above",
  labelWidth,
  enableEditorValid,
  ...props
}: MultiSelectProps) => {
  const showValidationMessage = validationMessage;
  const showHint = !showValidationMessage && hint;
  const hindId = showHint ? `${id}_hint` : '';
  const errorId = showValidationMessage ? `${id}_error` : '';

  return (
    <InputFieldWrapper
      label={label}
      size={size}
      valid = {valid}
      disabled={disabled}
      required={required}
      validationMessage={validationMessage}
      hint={hint}
      id = {id}
      displayLabel={displayLabel}
      labelWidth={labelWidth}
      enableEditorValid={enableEditorValid}
      fieldWrapperProps={fieldWrapperProps}
    >
      <StyledMultiSelectDropdown
        $hasSize={size}
        valid={valid}
        disabled={disabled}
        {...props}
      />
    </InputFieldWrapper>
  );
};

export default MultiSelectDropdown;
