import styled, { css } from 'styled-components';
import { MultiSelect as KMultiSelect } from '@progress/kendo-react-dropdowns';
import { rem, colors, opacity, inputHeight, fontSize } from '../../../utils';
import { MultiSelectProps } from '../multi-select-dropdown';

export const StyledMultiSelectDropdown = styled(KMultiSelect)<MultiSelectProps>`
  &&& {
    width: 100%;
    background-color: ${colors.white};
    border: ${({ valid }) =>
      valid
        ? `${rem(1)} solid ${colors.gray200}`
        : `${rem(1)} solid ${colors.red}`};

    &:focus-within {
      border: 1px solid ${colors.purple};
      box-shadow: 0 0 0 4px
        ${({ valid }) => (valid ? '#872c8c3f' : opacity(colors.darkRed, 0.25))};
    }

    &:hover {
      border: 1px solid ${colors.gray300};
    }

    & div > div {
      background-color: ${colors.gray100};
      border: none;
      & span:last-of-type > span {
        color: ${colors.gray400};
      }
    }
    height:auto;
    ${({ $hasSize }) => {
      switch ($hasSize) {
        case 'xx-small':
          return css`
            padding: ${rem(0)} ${rem(0)} ${rem(0)} ${rem(4)};
            min-height: ${inputHeight.xxsm};
            & div{
              padding:0;
              > div {
                height: auto;
                padding: 2px;
                font-size:${fontSize.xxSmall};
              }
            }
            .k-icon{
              font-size:${fontSize.xxSmall};
            }
            input{
              padding:0;
              font-size:${fontSize.xxSmall};
            } 
          `;
        case 'x-small':
        return css`
          min-height: ${inputHeight.xsm};
          padding: ${rem(0)} ${rem(0)} ${rem(0)} ${rem(4)};
          & div{
            padding:0;
            > div {
              height: auto;
              padding: 2px;
              font-size:${fontSize.xSmall};
            }
          }
          .k-icon{
            font-size:${fontSize.xSmall};
          }
          input{
            padding:0;
            font-size:${fontSize.xSmall};
          } 
        `;
        case 'small':
        return css`
          min-height: ${inputHeight.sm};
          padding: ${rem(0)} ${rem(0)} ${rem(0)} ${rem(4)};
          & div{
            padding:0;
            > div {
              height: auto;
              padding: 4px;
              font-size:${fontSize.small};
            }
          }
          .k-icon{
            font-size:${fontSize.small};
          }
          input{
            padding:0;
            font-size:${fontSize.small};
          } 
        `;
        case 'normal':
          return css`
            padding: ${rem(2)} ${rem(0)} ${rem(0)} ${rem(4)};
            min-height: ${inputHeight.normal};
            & div{
              padding:0;
              > div {
                height: ${rem(24)};
                font-size:${fontSize.normal};
              }
            }
            .k-icon{
              font-size:${fontSize.normal};
            }
            input{
              padding:0;
              font-size:${fontSize.normal};
            } 
          `;
        case 'medium':
            return css`
              min-height: ${inputHeight.md};
              padding: ${rem(0)} ${rem(2)} ${rem(0)} ${rem(4)};
              & div{
                padding:4px;
                > div {
                  height: ${rem(30)};
                  font-size:${fontSize.medium};
                }
              }
              .k-icon{
                font-size:${fontSize.medium};
              }
              input{
                padding:0;
                font-size:${fontSize.medium};
              } 
            `;
        case 'large':
          return css`
            min-height: ${inputHeight.lg};
            padding: ${rem(0)} ${rem(4)} ${rem(0)} ${rem(4)};
            & div{
              padding:6px;
              > div {
                height: ${rem(35)};
                font-size:${fontSize.large};
              }
            }
            .k-icon{
              font-size:${fontSize.large};
            }
            input{
              padding:0;
              font-size:${fontSize.large};
            } 
          `;
        case 'x-large':
          return css`
            min-height: ${inputHeight.xlg};
            padding: ${rem(0)} ${rem(4)} ${rem(0)} ${rem(8)};
            & div{
              padding:8px;
              margin-right:5px;
              > div {
                height: ${rem(35)};
                font-size:${fontSize.xLarge};
              }
            }
            .k-icon{
              font-size:${fontSize.xLarge};
            }
            input{
              padding:0;
              font-size:${fontSize.xLarge};
            } 
          `;
        case 'xx-large':
          return css`
            min-height: ${inputHeight.xxlg};
            padding: ${rem(0)} ${rem(4)} ${rem(0)} ${rem(10)};
            & div{
              margin-right: 5px;
              padding: 8px;
              > div {
                height: ${rem(35)};
                font-size:${fontSize.xxLarge};
              }
            }
            .k-icon{
              font-size:${fontSize.xxLarge};
            }
            input{
              padding:0;
              font-size:${fontSize.xxLarge};
            } 
          `;
        default:
          return css`
              min-height: ${inputHeight.sm}
              font-size:${fontSize.small};
              input{
                padding:0;
                font-size:${fontSize.small};
              } 
          `;
      }
    }}

    ${({ disabled }) =>
      disabled &&
      css`
        background-color: ${colors.disabledBackground};
        border-color: ${colors.gray300};
      `}
  }
`;
