import styled, { css } from 'styled-components';
import { Badge as KBadge } from '@progress/kendo-react-indicators';
import { colors, rem, fontWeights } from '../../../utils';
import { BadgeProps } from '../pill';

const borderWidth = rem(2);

export const StyledPill = styled(KBadge)<BadgeProps>`
  &&& {
    line-height: ${rem(14)};
    font-size: ${rem(11)};
    padding: 0 10px;
    background-color: ${colors.white};
    color: ${colors.gray500};
    font-weight: ${fontWeights.bold};
    text-transform: uppercase;
    position: relative;
    z-index: 1;
    width: ${rem(78)};
    height: auto;
    width: auto;
    border-radius:9999px;

    & span {
      padding: ${rem(3)} 0;
    }

    ${({ variant }) => {
      switch (variant) {
        case 'error':
          return css`
            border: ${borderWidth} solid ${colors.red};
          `;
        case 'warning':
          return css`
            border: ${borderWidth} solid ${colors.orange};
          `;
        case 'success':
          return css`
            border: ${borderWidth} solid ${colors.green};
          `;
        default:
          return css`
            border: ${borderWidth} solid ${colors.gray500};
          `;
      }
    }}
    ${({ size }) => {
      switch (size) {
        case 'small':
          return css`
            line-height: ${rem(14)};
            font-size: ${rem(11)};
            padding: 0 10px;
          `;
        case 'medium':
          return css`
            line-height: ${rem(16)};
            font-size: ${rem(14)};
            padding: 2px 12px;
          `;
        case 'large':
          return css`
            line-height: ${rem(18)};
            font-size: ${rem(16)};
            padding: 4px 14px;
          `;
        default:
          return ;
      }
    }}
  }
`;
