import React, { useState, useRef } from 'react';
import styled from 'styled-components';
import {
  Popover as KPopover,
  PopoverProps as KPopoverProps,
  PopoverPosition,
} from '@progress/kendo-react-tooltip';
import { IconNavMoreoptions } from '../icons/components';
import { rem, colors } from '../../utils';
import { useClickOutside } from '../../utils/hooks';

/* eslint-disable-next-line */
export interface PopoverProps extends KPopoverProps {
  /* todo */
  position?: PopoverPosition;
  /* todo */
  popoverContent?: React.ReactNode;
  /* todo */
  trigger?: 'burger' | string;
  /* todo */
  iconSize?: string | number;
  /* todo */
  customTrigger?: React.ReactNode;
}

const StyledPopover = styled(KPopover)``;

const StyledButton = styled.button`
  display: flex;
  align-items: center;
  background-color: transparent;
  padding: ${rem(3)};
  border-radius: ${rem(4)};
  border: ${rem(1)} solid transparent;

  &:hover {
    background: ${colors.white};
    border: ${rem(1)} solid ${colors.darkMauve};
    color: ${colors.darkMauve};
  }

  &:focus {
    box-shadow: 0 0 0 ${rem(4)} #872c8c3f;
  }
`;

export const Popover = ({
  position = 'bottom',
  popoverContent = null,
  trigger = 'burger',
  iconSize = 20,
  customTrigger,
  appendTo,
  ...props
}: PopoverProps) => {
  const anchor = useRef(null);
  const [show, setShow] = useState(false);

  const onClick = () => setShow(!show);

  useClickOutside(anchor, () => {
    if (show) setShow(false);
  },appendTo);

  return (
    <>
      <StyledButton type="button" onClick={onClick} ref={anchor}>
        {trigger === 'burger' && !customTrigger ? (
          <IconNavMoreoptions
            fill={colors.gray400}
            fontSize={`${iconSize}px`}
          />
        ) : (
          customTrigger || '-'
        )}
      </StyledButton>
      <StyledPopover
        show={show}
        anchor={anchor.current && anchor.current}
        position={position}
        appendTo={appendTo}
        {...props}
      >
        {popoverContent}
      </StyledPopover>
    </>
  );
};

export default Popover;
