import styled, { css } from 'styled-components';
import {
  ProgressBar as KProgressBar,
  ProgressBarProps as KProgressBarProps,
} from '@progress/kendo-react-progressbars';
import { rem, colors } from '../../utils';
import '../../theme/base-theme.scss';

/* eslint-disable-next-line */
export interface ProgressBarProps extends KProgressBarProps {
  /** todo */
  variant?: 'success' | 'error' | 'warning';
  /** trans props */
  $variant?: string;
}

const StyledProgressBar = styled(KProgressBar)<ProgressBarProps>`
  &&& {
    height: ${rem(14)};
    border-radius: ${rem(10)};
    grid-template-rows: 0%;

    & div:last-of-type {
      grid-row: auto;
      ${({ $variant }) => {
        switch ($variant) {
          case 'success':
            return css`
              background-color: ${colors.green};
            `;
          case 'error':
            return css`
              background-color: ${colors.red};
            `;
          case 'warning':
            return css`
              background-color: ${colors.orange};
            `;
          default:
            return css`
              background-color: ${colors.extralightIndigo};
            `;
        }
      }}
    }
  }
`;

export const ProgressBar = ({
  variant = 'success',
  animation = true,
  labelVisible = false,
  ...props
}: ProgressBarProps) => {
  return (
    <StyledProgressBar
      animation={animation}
      $variant={variant}
      labelVisible={labelVisible}
      {...props}
    />
  );
};

export default ProgressBar;
