import { useState, useCallback } from 'react';
import { Meta } from '@storybook/react';
import { StyledGrid } from './styled-grid';
import {
  Grid,
  GridColumn,
  GridToolbar,
  GridColumnMenuSort,
  GridColumnMenuFilter,
  GridColumnMenuGroup,
  getSelectedState,
} from '@progress/kendo-react-grid';
import { getter } from '@progress/kendo-react-common';
import Pill from '../pill/pill';
import Button from '../button/button';
import data from './data.json';
import { IconExpandCircle } from '@bamboorose/br-components';

export default {
  component: StyledGrid,
  title: 'Wrapper/StyledGrid',
} as Meta;

const DATA_ITEM_KEY = 'ProductID';
const SELECTED_FIELD = 'selected';
const idGetter = getter(DATA_ITEM_KEY);

export const Primary = () => {
  const [dataState, setDataState] = useState(
    data.map((dataItem) =>
      Object.assign(
        {
          selected: false,
        },
        dataItem
      )
    )
  );
  const [selectedState, setSelectedState] = useState({});

  const onSelectionChange = useCallback(
    (event) => {
      console.log(typeof event);
      const newSelectedState = getSelectedState({
        event,
        selectedState: selectedState,
        dataItemKey: DATA_ITEM_KEY,
      });
      setSelectedState(newSelectedState);
    },
    [selectedState]
  );

  const onHeaderSelectionChange = useCallback((event) => {
    const checkboxElement = event.syntheticEvent.target;
    const checked = checkboxElement.checked;
    const newSelectedState = {};
    event.dataItems.forEach((item) => {
      newSelectedState[idGetter(item)] = checked;
    });
    setSelectedState(newSelectedState);
  }, []);

  const ColumnMenu = (props: object) => {
    console.log(typeof props);
    return (
      <div>
        <GridColumnMenuSort {...props} />
        <GridColumnMenuFilter {...props} />
        <GridColumnMenuGroup {...props} />
      </div>
    );
  };

  const Status = ({ ariaColumnIndex, columnIndex, colSpan }: any) => (
    <td
      colSpan={colSpan}
      role="gridcell"
      aria-colindex={ariaColumnIndex}
      aria-selected="false"
      data-grid-col-index={columnIndex}
    >
      <Pill variant="success" label={'success'} />
    </td>
  );

  const SupplierNameButton = ({
    dataItem: { SupplierName },
    ariaColumnIndex,
    columnIndex,
    colSpan,
  }: string) => (
    <td
      colSpan={colSpan}
      role="gridcell"
      aria-colindex={ariaColumnIndex}
      aria-selected="false"
      data-grid-col-index={columnIndex}
    >
      <Button variant="flat" size="medium">
        {SupplierName}
      </Button>
    </td>
  );

  const CategoryNameButton = ({
    dataItem: { CategoryName },
    ariaColumnIndex,
    columnIndex,
    colSpan,
  }: string) => {
    return (
      <td
        colSpan={colSpan}
        role="gridcell"
        aria-colindex={ariaColumnIndex}
        aria-selected="false"
        data-grid-col-index={columnIndex}
      >
        <Button variant="flat" size="medium">
          {CategoryName}
        </Button>
      </td>
    );
  };

  return (
    // This is the StyledGrid wrapper component that should wrap a Kendo Grid component.
    <StyledGrid variant="primary" isFullWidth={true}>
      <Grid
        rowHeight={64}
        scrollable="none"
        resizable
        selectable={{
          enabled: true,
          drag: false,
          cell: false,
          mode: 'multiple',
        }}
        data={dataState.map((item) => ({
          ...item,

          [SELECTED_FIELD]: selectedState[idGetter(item)],
        }))}
        dataItemKey={DATA_ITEM_KEY}
        selectedField={SELECTED_FIELD}
        onSelectionChange={onSelectionChange}
        onHeaderSelectionChange={onHeaderSelectionChange}
      >
        <GridColumn
          field={SELECTED_FIELD}
          headerSelectionValue={
            dataState.findIndex((item) => !selectedState[idGetter(item)]) === -1
          }
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={Status}
          field="ProductName"
          title="Product Name"
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={SupplierNameButton}
          field="SupplierName"
          title="Supplier Name"
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={CategoryNameButton}
          field="CategoryName"
          title="Category Name"
        />
      </Grid>
    </StyledGrid>
  );
};

export const Secondary = () => {
  const [dataState, setDataState] = useState(
    data.map((dataItem) =>
      Object.assign(
        {
          selected: false,
        },
        dataItem
      )
    )
  );
  const [selectedState, setSelectedState] = useState({});

  const onSelectionChange = useCallback(
    (event) => {
      console.log(typeof event);
      const newSelectedState = getSelectedState({
        event,
        selectedState: selectedState,
        dataItemKey: DATA_ITEM_KEY,
      });
      setSelectedState(newSelectedState);
    },
    [selectedState]
  );

  const onHeaderSelectionChange = useCallback((event) => {
    const checkboxElement = event.syntheticEvent.target;
    const checked = checkboxElement.checked;
    const newSelectedState = {};
    event.dataItems.forEach((item) => {
      newSelectedState[idGetter(item)] = checked;
    });
    setSelectedState(newSelectedState);
  }, []);

  const ColumnMenu = (props: object) => {
    console.log(typeof props);
    return (
      <div>
        <GridColumnMenuSort {...props} />
        <GridColumnMenuFilter {...props} />
        <GridColumnMenuGroup {...props} />
      </div>
    );
  };

  const Status = ({ ariaColumnIndex, columnIndex, colSpan }: any) => (
    <td
      colSpan={colSpan}
      role="gridcell"
      aria-colindex={ariaColumnIndex}
      aria-selected="false"
      data-grid-col-index={columnIndex}
    >
      <Pill variant="success" label={'success'} />
    </td>
  );

  const SupplierNameButton = ({
    dataItem: { SupplierName },
    ariaColumnIndex,
    columnIndex,
    colSpan,
  }: string) => (
    <td
      colSpan={colSpan}
      role="gridcell"
      aria-colindex={ariaColumnIndex}
      aria-selected="false"
      data-grid-col-index={columnIndex}
    >
      <Button variant="flat" size="medium">
        {SupplierName}
      </Button>
    </td>
  );

  const CategoryNameButton = ({
    dataItem: { CategoryName },
    ariaColumnIndex,
    columnIndex,
    colSpan,
  }: string) => {
    return (
      <td
        colSpan={colSpan}
        role="gridcell"
        aria-colindex={ariaColumnIndex}
        aria-selected="false"
        data-grid-col-index={columnIndex}
      >
        <Button variant="flat" size="medium">
          {CategoryName}
        </Button>
      </td>
    );
  };

  return (
    // This is the StyledGrid wrapper component that should wrap a Kendo Grid component.
    <StyledGrid variant="secondary" isFullWidth={true}>
      <Grid
        rowHeight={64}
        scrollable="none"
        resizable
        selectable={{
          enabled: true,
          drag: false,
          cell: false,
          mode: 'multiple',
        }}
        data={dataState.map((item) => ({
          ...item,

          [SELECTED_FIELD]: selectedState[idGetter(item)],
        }))}
        dataItemKey={DATA_ITEM_KEY}
        selectedField={SELECTED_FIELD}
        onSelectionChange={onSelectionChange}
        onHeaderSelectionChange={onHeaderSelectionChange}
      >
        <GridColumn
          field={SELECTED_FIELD}
          headerSelectionValue={
            dataState.findIndex((item) => !selectedState[idGetter(item)]) === -1
          }
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={Status}
          field="ProductName"
          title="Product Name"
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={SupplierNameButton}
          field="SupplierName"
          title="Supplier Name"
        />
        <GridColumn
          columnMenu={ColumnMenu}
          cell={CategoryNameButton}
          field="CategoryName"
          title="Category Name"
        />
      </Grid>
    </StyledGrid>
  );
};

export const Condensed = () => {
  return (
    // This is the StyledGrid wrapper component that should wrap a Kendo Grid component.
    <StyledGrid variant="condensed" isFullWidth={true}>
      <Grid scrollable="none" resizable data={data}>
        <GridColumn field="ProductName" title="Product Name" />
        <GridColumn field="SupplierName" title="Supplier Name" />
      </Grid>
    </StyledGrid>
  );
};

export const CondensedEdit = () => {
  const [data, setData] = useState([
    {
      ProductID: 1,
      ProductName: 'Product Name',
      SupplierName: 'Supplier Name',
    },
    {
      ProductID: 2,
      ProductName: 'Product Name',
      SupplierName: 'Supplier Name',
    },
    {
      ProductID: 3,
      ProductName: 'Product Name',
      SupplierName: 'Supplier Name',
    },
    {
      ProductID: 4,
      ProductName: 'Product Name',
      SupplierName: 'Supplier Name',
    },
  ]);
  const [editID, setEditID] = useState(null);

  const rowClick = (event) => {
    setEditID(event.dataItem.ProductID);
  };

  const itemChange = (event) => {
    const inEditID = event.dataItem.ProductID;
    const field = event.field || '';
    const newData = data.map((item) =>
      item.ProductID === inEditID ? { ...item, [field]: event.value } : item
    );
    setData(newData);
  };

  const addRecord = () => {
    const newRecord = {
      ProductID: data.length + 1,
    };
    setData([newRecord, ...data]);
    setEditID(newRecord.ProductID);
  };

  return (
    // This is the StyledGrid wrapper component that should wrap a Kendo Grid component.
    <StyledGrid variant="condensed" isFullWidth={true}>
      <Grid
        scrollable="none"
        resizable
        data={data.map((item) => ({
          ...item,
          inEdit: item.ProductID === editID,
        }))}
        editField="inEdit"
        onRowClick={rowClick}
        onItemChange={itemChange}
      >
        <GridColumn field="ProductName" title="Product Name" />
        <GridColumn field="SupplierName" title="Supplier Name" />
        <GridToolbar>
          <Button variant="icon-text-flat" onClick={addRecord}>
            <>
              <IconExpandCircle fontSize={'25px'} />
              <span>Add</span>
            </>
          </Button>
        </GridToolbar>
      </Grid>
    </StyledGrid>
  );
};
