import styled, { css } from 'styled-components';
import { colors, rem, opacity, fontWeights, fontSize } from '../../../utils';
import { StyledGridProps } from '../styled-grid';

export const StyledGridWrap = styled.div<StyledGridProps>`
  &&& {
    table {
      border-spacing: 0;
    }

    ${({ isFullWidth }) =>
      isFullWidth &&
      css`
        table {
          width: 100%;
        }
      `}

    thead {
      text-align: left;
    }

    th {
      height: ${rem(60)};
      border-width: 0;

      ${({ variant }) => {
        switch (variant) {
          case 'primary':
            return css`
              background-color: ${colors.white};
            `;
          case 'secondary':
            return css`
              background-color: ${colors.gray100};
            `;
          case 'condensed':
            return css`
              background-color: ${colors.gray100};
              height: ${rem(0)};
              & > span {
                & > span {
                  text-transform: uppercase;
                  font-size: ${rem(10)};
                  font-weight: ${fontWeights.bold};
                }
              }
            `;
          default:
            return css`
              background-color: ${colors.white};
            `;
        }
      }}

      border-bottom: solid ${rem(1)} ${colors.gray100};
      ${({ variant }) =>
        variant === 'condensed'
          ? css`
              padding: ${rem(18)} ${rem(20)};
            `
          : css`
              padding: 0 ${rem(20)} 0 ${rem(20)};
            `}
      font-size: ${rem(11)};
      font-weight: ${fontWeights.bold};
      color: ${colors.gray500};
      text-transform: uppercase;

      & span {
        display: flex;
        align-items: center;
        & span {
          margin-right: ${rem(8)};
        }
      }
    }

    td {
      border-width: 0;
      padding: ${({ variant }) =>
        variant === 'condensed' ? rem(14) : rem(20)};
      font-weight: ${fontWeights.regular};
      font-size: ${fontSize.small};
      color: ${colors.gray500};
      border-bottom: solid ${rem(1)} ${colors.gray100};
    }

    && {
      &&& .k-selected {
        background-color: ${colors.extraLightViolet};
        border: none;
      }
      tr {
        background-color: ${colors.white};
        &:hover {
          background-color: ${({ variant }) =>
            variant === 'condensed'
              ? colors.white
              : opacity(colors.extraLightViolet, 0.2)};
        }
      }
    }

    .k-toolbar {
      background-color: ${colors.white};
      border: none;
    }
  }
`;
