import styled, { css } from 'styled-components';
import { TabStrip as KTabStrip } from '@progress/kendo-react-layout';
import { rem, colors, fontWeights, fontSize } from '../../../utils';
import { TabStripProps } from '../tab-strip';

export const StyledTabStrip = styled(KTabStrip)<TabStripProps>`
  & div:first-of-type {
    & li {
      & span {
        display: flex;
        justify-content: center;
      }
    }
  }

  ${({ variant }) => {
    switch (variant) {
      case 'global':
        return css`
          &&& {
            height: ${rem(30)};
            & > div {
              background-color: transparent;
              padding: 0;
              border-left: none;
              border-right: none;
              border-color: transparent;
              overflow:initial;
            }
            li {
              background-color: transparent;
              font-weight: ${fontWeights.regular};
              font-size: ${fontSize.small};
              margin-bottom: ${rem(3)};
              & > span {
                padding-top: ${rem(3)};
                color: ${colors.white};
              }

              ${({ selected }: any) => css`
                &:nth-child(${selected + 1}) {
                  background-color: ${colors.white};
                  font-weight: ${fontWeights.semiBold};
                  & > span {
                    color: ${colors.gray500};
                  }
                }
              `}

              &:active {
                background-color: ${colors.white};
              }
            }
          }
        `;
      case 'secondary':
        return css`
          & .k-content {
            border: none;
            & > div {
              width: 100%;
            }
          }
          & > div:first-of-type {
            border: none;
            & > ul > li {
              border: none;
              color: ${colors.indigo};
              font-size: ${fontSize.small};
              font-weight: ${fontWeights.semiBold};
              &:hover {
                color: ${colors.purple};
              }
              padding: ${rem(6)} ${rem(6)};
              & > span {
                padding: 0;
                padding-bottom:${rem(3)};
                flex-grow:0;
              }
              ${({ selected }: any) => css`
                &:nth-child(${selected + 1}) {
                  color: ${colors.purple};
                  & > span {
                    border-bottom: ${rem(3)} solid ${colors.purple};
                  }
                }
              `}
            }
          }
        `;
      default:
        return css`
          &&& {
            & .k-content > div {
              width: 100%;
            }
            & > div {
              display: flex;
              padding: 0;
              border-left: none;
              border-right: none;
              border: none;
            }
            li {
              background-color: ${colors.gray500};
              font-weight: ${fontWeights.semiBold};
              font-size: ${fontSize.large};
              margin-right: ${rem(2)};
              & > span {
                color: ${colors.white};
              }

              ${({ selected }: any) => css`
                &:nth-child(${selected + 1}) {
                  background-color: ${colors.purple};
                }
              `}

              &:active {
                background-color: ${colors.purple};
              }
            }
          }
        `;
    }
  }}
`;
