import { useState } from 'react';
import { Meta } from '@storybook/react';
import styled from 'styled-components';
import { colors, rem, fontWeights } from '../../utils';
import { TabStripProps } from '../tab-strip/tab-strip';
import { TabStrip } from './tab-strip';

const StyledPlaceholder = styled.div`
  &&& {
    display: flex;
    justify-content: center;
    font-size: 20px;
    font-weight: ${fontWeights.semiBold};
    max-width: 800px;
    background-color: #d3e6fa;
    border: 1px #6162a1 solid;
    border-radius: ${rem(4)};
    margin: ${rem(10)};
    padding: ${rem(30)};
  }
`;

const StyledContainer = styled.div`
  display: flex;
  align-items: end;
  height: ${rem(40)};
  width: 100%;
  background: linear-gradient(0.25turn, ${colors.violet}, ${colors.cherry});
  padding-left: ${rem(20)};
`;

export default {
  component: TabStrip,
  title: 'Layout/TabStrip',
} as Meta;

export const Primary = ({ ...args }: TabStripProps) => {
  const [selected, setSelected] = useState(1);
  const handleSelect = (e) => setSelected(e.selected);

  return (
    <TabStrip {...args} selected={selected} onSelect={handleSelect}>
      <TabStrip.Tab title="Dashboard">
        <StyledPlaceholder>Dashboard</StyledPlaceholder>
      </TabStrip.Tab>
      <TabStrip.Tab title="List">
        <StyledPlaceholder>List</StyledPlaceholder>
      </TabStrip.Tab>
      <TabStrip.Tab title="Claims Management">
        <StyledPlaceholder>Claims Management</StyledPlaceholder>
      </TabStrip.Tab>
    </TabStrip>
  );
};

export const Secondary = ({ ...args }: TabStripProps) => {
  const [selected, setSelected] = useState(1);
  const handleSelect = (e) => setSelected(e.selected);

  return (
    <TabStrip
      {...args}
      variant="secondary"
      selected={selected}
      onSelect={handleSelect}
    >
      <TabStrip.Tab title="Dashboard">
        <StyledPlaceholder>Dashboard</StyledPlaceholder>
      </TabStrip.Tab>
      <TabStrip.Tab title="List">
        <StyledPlaceholder>List</StyledPlaceholder>
      </TabStrip.Tab>
      <TabStrip.Tab title="Claims Management">
        <StyledPlaceholder>Claims Management</StyledPlaceholder>
      </TabStrip.Tab>
    </TabStrip>
  );
};

export const Global = ({ ...args }: TabStripProps) => {
  const [selected, setSelected] = useState(1);
  const handleSelect = (e) => setSelected(e.selected);

  return (
    <StyledContainer>
      <TabStrip
        {...args}
        variant="global"
        selected={selected}
        onSelect={handleSelect}
      >
        <TabStrip.Tab title="Marketplace">
          <StyledPlaceholder>Marketplace</StyledPlaceholder>
        </TabStrip.Tab>
        <TabStrip.Tab title="Trade Solutions">
          <StyledPlaceholder>Trade Solutions</StyledPlaceholder>
        </TabStrip.Tab>
      </TabStrip>
    </StyledContainer>
  );
};
