import { useState } from 'react';
import { Meta } from '@storybook/react';
import { Tile } from './tile';
import styled, { css } from 'styled-components';
import { rem, colors } from '../../utils';
import { TileProps } from './tile';
import Button from '../button/button';
import Input from '../input/input';
import DropDownList from '../drop-down-list/drop-down-list';

const StylePlaceHolder = styled.div<{ $isHightLighted: boolean | undefined }>`
  display: flex;
  justify-content: center;
  align-items: center;
  width: ${rem(200)};
  height: ${rem(200)};
  background-color: ${colors.white};
  ${({ $isHightLighted }) =>
    $isHightLighted &&
    css`
      background-color: lightgray;
    `}
`;

export default {
  component: Tile,
  title: 'Layout/Tile',
  argTypes: {
    $hasVariant: {
      table: {
        disable: true,
      },
    },
    isCollapsible: {
      type: { name: 'boolean', required: false },
      defaultValue: true,
      control: {
        control: 'boolean',
      },
    },
    title: {
      control: {
        type: 'text',
      },
    },
    children: {
      control: {
        control: 'object',
      },
    },
  },
} as Meta;

export const Primary = ({ ...args }: TileProps) => {
  const [toggleExpand, setToggleExpand] = useState(false);
  const handleExpand = () => setToggleExpand(!toggleExpand);

  return (<>
  <button onClick={handleExpand}>Toggle</button>
    <Tile {...args} isCollapsed={toggleExpand} data-testid="tile-primary">
      <Tile.Header
        title="Header component"
        handleExpand={handleExpand}
        headerSubContent={<div>Header sub content</div>}
      />
      <Tile.Body isCollapsed={toggleExpand}>
        <StylePlaceHolder $isHightLighted={false}>
          Body component
        </StylePlaceHolder>
      </Tile.Body>
      <Tile.Footer>
        <div>Footer component</div>
      </Tile.Footer>
    </Tile></>
  );
};

export const Transparent = ({ ...args }) => {
  const [toggleExpand, setToggleExpand] = useState(false);
  const handleExpand = () => setToggleExpand(!toggleExpand);
  const { isCollapsible } = args;

  return (
    <Tile {...args} isCollapsible={isCollapsible}isCollapsed={toggleExpand} variant="transparent">
      <Tile.Header
        title="Header component"
        handleExpand={handleExpand}
      />
      <Tile.Body isCollapsed={toggleExpand}>
        <StylePlaceHolder $isHightLighted={true}>
          Body component
        </StylePlaceHolder>
      </Tile.Body>
    </Tile>
  );
};

export const Header = ({ ...args }) => {
  const [toggleExpand, setToggleExpand] = useState(false);
  const handleExpand = () => setToggleExpand(!toggleExpand);

  return (
    <Tile {...args} isCollapsible isCollapsed={toggleExpand}>
      <Tile.Header
        title="Header component"
        handleExpand={handleExpand}
      />
    </Tile>
  );
};

export const HeaderWithContent = ({ ...args }) => {
  const [toggleExpand, setToggleExpand] = useState(false);
  const handleExpand = () => setToggleExpand(!toggleExpand);

  const StyledLayout = styled.div`
    display: grid;
    grid-template-columns: 1fr 1fr;
    gap: 26px;
  `;

  return (
    <Tile {...args} isCollapsible isCollapsed={toggleExpand}>
      <Tile.Header
        title="Header with content"
        handleExpand={handleExpand}
        headerSubContent={<div>Header sub content</div>}
        headerRightContent={
          <StyledLayout>
            <Input icon="search" />
            <DropDownList data={['first', 'second', 'last']} />
          </StyledLayout>
        }
      />
    </Tile>
  );
};

export const Body = ({ ...args }) => {
  return (
    <Tile {...args}>
      <Tile.Body>
        <StylePlaceHolder $isHightLighted={false}>
          Body component
        </StylePlaceHolder>
      </Tile.Body>
    </Tile>
  );
};

export const Footer = ({ ...args }) => {
  return (
    <Tile {...args}>
      <Tile.Footer>
        <div>Footer component</div>
      </Tile.Footer>
    </Tile>
  );
};
