import styled, { css } from 'styled-components';
import { Card as KCard } from '@progress/kendo-react-layout';
import { Header, Body, Footer } from './components';
import { TileContext } from './context/tile-context';
import { useEffect, useState } from 'react';

/* eslint-disable-next-line */
export interface TileProps {
  /** ```Tile props```
   * Enable or disable collapsible features
   * if true/false, can toggle show/hide Tile.Body content
   */
  isCollapsible?: boolean;
  /** ```Tile Props```
   * if true - default tile will be collapse
   * else false - default tile will be expanded
   */
   isCollapsed?: boolean;
  /** Content of tile
   * i.e. Tile.Header, Tile.Body, Tile.Footer or any other content of Tile
   */
  children?: React.ReactNode;
  /** ```Tile.Header props```
   * right content of tile header such as search fields
   */
  headerRightContent?: React.ReactNode;
  /** ```Tile.Header Props```
   * title o tile header
   */
  title?: string;
  /** ```Tile.header Props```
   * expand/collapse call back method with collapse state as boolean args
   * if isCollapse, arguments is true
   */
  handleExpand?: (isCollapsed: boolean) => void;
  /** ```Tile props```
   * to control if tile should be transparent or not
   * value ```transparent```
   */
  variant?: string;
  /** transient props */
  $hasVariant?: string;
  /** 
   * ```Tile.Header props```
   * show/hide toggle icon */
  showToggleIcon?: boolean;
  /** 
   * ```Tile.Header props```
   * Header sub content */
  headerSubContent?: React.ReactNode;
  /** className */
  className?: string;
}

const StyledTile = styled.div<TileProps>`
  ${({ $hasVariant }) =>
    $hasVariant === 'transparent' &&
    css`
      border: none;
    `}
`;

export const Tile = ({
  isCollapsible = true,
  children,
  variant = '',
  isCollapsed=false,
  className="",
  ...others
}: TileProps) => {
  const [_isCollapsed,setIsCollapsed]=useState(isCollapsed);
  useEffect(()=>{
    setIsCollapsed(isCollapsed);
  },[isCollapsed])
  function updateContext(contextProps){
    setIsCollapsed(contextProps.isCollapsed)
    return ;
  }
  return (
    <TileContext.Provider
      value={{
        subComponents: children,
        isCollapsible,
        isCollapsed:_isCollapsed,
        variant,
        updateContext
      }}
    >
      <StyledTile $hasVariant={variant} className={`k-card ${className}`} {...others}>
        {children}
      </StyledTile>
    </TileContext.Provider>
  );
};

Tile.Header = Header;
Tile.Body = Body;
Tile.Footer = Footer;

export default Tile;
