import { useState, useEffect } from 'react';
import styled, { css } from 'styled-components';
import { rem, opacity } from '../../utils';
import Button from '../button/button';
import {
  IconNavChevonright,
  IconNavChevonleft,
  IconNavArrowtailLeft,
  IconNavArrowtailRight,
} from '../icons/components';

export interface ToggleButtonGroupProps {
  /** todo */
  iconSize?: number;
  /** todo */
  iconColor?: string;
  /** todo */
  buttonSize?: 'small' | 'medium' | 'large' | any;
  /** todo */
  onClick: (e: object) => void;
  /** todo */
  hasBorder?: boolean;
  /** todo */
  iconType?: 'primary' | 'secondary' | string;
  /** transeant prop */
  $transientBorder?: boolean;
}

const StyledToggleButtonGroup = styled.div.attrs((): any => ({
  role: 'group',
}))`
  display: flex;
  flex-wrap: nowrap;
  align-items: center;
  button:first-of-type {
    ${({ $transientBorder }) =>
      !$transientBorder &&
      css`
        border: none;
        background-color: transparent;
      `}
    &:disabled {
      opacity: 1;
    }
  }
  button:last-of-type {
    margin-left: ${({ $transientBorder }) => ($transientBorder ? rem(5) : 0)};
    ${({ $transientBorder }) =>
      !$transientBorder &&
      css`
        border: none;
        background-color: transparent;
      `}
    &:disabled {
      opacity: 1;
    }
  }
`;

export const ToggleButtonGroup = ({
  iconSize = 25,
  iconColor = '#333333',
  buttonSize = 'small',
  hasBorder = true,
  iconType = 'primary',
  onClick = () => {},
  ...props
}: ToggleButtonGroupProps) => {
  const [toggleArrors, setToggelArrows] = useState<{
    left: boolean;
    right: boolean;
  }>({
    left: false,
    right: true,
  });

  const handleArrowClick = () => {
    setToggelArrows((prev) => ({
      ...prev,
      left: !prev.left,
      right: !prev.right,
    }));
  };

  useEffect(() => onClick(toggleArrors), [toggleArrors]);

  return (
    <StyledToggleButtonGroup $transientBorder={hasBorder} {...props}>
      <Button
        variant="icon"
        type="button"
        size={buttonSize}
        onClick={handleArrowClick}
        disabled={toggleArrors?.left}
      >
        {iconType === 'primary' ? (
          <IconNavArrowtailLeft
            fontSize={rem(iconSize)}
            stroke={`${
              toggleArrors?.left ? iconColor : opacity(iconColor, 0.5)
            }`}
          />
        ) : (
          <IconNavChevonleft
            fontSize={rem(iconSize)}
            fill={`${toggleArrors?.left ? iconColor : opacity(iconColor, 0.5)}`}
          />
        )}
      </Button>
      <Button
        type="button"
        variant="icon"
        onClick={handleArrowClick}
        disabled={toggleArrors?.right}
      >
        {iconType === 'primary' ? (
          <IconNavArrowtailRight
            fontSize={rem(iconSize)}
            stroke={`${
              toggleArrors?.right ? iconColor : opacity(iconColor, 0.5)
            }`}
          />
        ) : (
          <IconNavChevonright
            fontSize={rem(iconSize)}
            fill={`${
              toggleArrors?.right ? iconColor : opacity(iconColor, 0.5)
            }`}
          />
        )}
      </Button>
    </StyledToggleButtonGroup>
  );
};

export default ToggleButtonGroup;
