import { useRef } from 'react';
import styled from 'styled-components';
import {
  Tooltip as KTooltip,
  TooltipProps as KTooltipProps,
} from '@progress/kendo-react-tooltip';
import { IconInfoOutline } from '../icons/components';
import { colors } from '../../utils';

/* eslint-disable-next-line */
export interface TooltipProps extends KTooltipProps {
  /** todo */
  iconSize: string | number;
  /** todo */
  iconColor: string;
  /** todo */
  message: string;
}

const StyledTooltip = styled(KTooltip)``;

export const Tooltip = ({
  iconSize = '30',
  iconColor = colors.gray500,
  position = 'right',
  message = '',
  ...props
}: TooltipProps) => {
  const tooltip = useRef<KTooltip>(null);

  return (
    <div
      onMouseOver={(event) =>
        tooltip.current && tooltip.current.handleMouseOver(event)
      }
      onMouseOut={(event) =>
        tooltip.current && tooltip.current.handleMouseOut(event)
      }
    >
      <IconInfoOutline
        title={message}
        fontSize={`${iconSize}px`}
        fill={iconColor}
      />
      <StyledTooltip
        ref={tooltip}
        anchorElement="target"
        position={position}
        {...props}
      />
    </div>
  );
};

export default Tooltip;
