import { StyledTypography } from "./styles";
import { TypographyProps as KTypographyProps } from "@progress/kendo-react-common";

import H1 from "./components/h1/H1";
import H2 from "./components/h2/H2";
import H3 from "./components/h3/H3";
import H4 from "./components/h4/H4";
import H5 from "./components/h5/H5";
import H6 from "./components/h6/H6";
import P from "./components/p/P";
import Pre from "./components/pre/Pre";
import Code from "./components/code/Code";

/* eslint-disable-next-line */

export interface TypographyProps extends  KTypographyProps {
  /**
   * Predefined font size for typography
   * * xx-small: 10px;
   * * x-small:12px;
   * * small:14px;
   * * normal:16px;
   * * large:18px;
   * * x-large:24px;
   * * xx-large:32px;
   */
  size?: 'xx-small' |'x-small'| 'small'|'normal' | 'medium' | 'large' |'x-large'|'xx-large'| null;
  children?:React.ReactNode,
  /**
   * Predefined text theme color
   */
  themeColor?	:"error" | "inverse" | "inherit" | "success" | "dark" | "light" | "primary" | "secondary" | "tertiary" | "info" | "warning"|undefined,
  /**
   * custom color can be set with color props.
   **when color is set, it override predefined themecolor text
   */
  color?: string, 
  /**
   * Apart from predefined, custom font size can be set as well. 
   ** when fontsize is set, it override any predefined size 
   * //for some reason, Omit fontSize type is not working with extending this KTypographyProps, hence custom $fontSize prop is exposed
   */
  fontSize?: number|any ,
  textDecoration?: "strikethrough"| "underline" | "italic"|"overline"  |"none" |undefined,
  /**
  * Overrides the font weight applied by the theme typography styles [see example]({% slug appearance_typography %}#toc-font-weight).
  * The possible values are:
  * - `light` font-weight: 300
  * - `regular` font-weight: 400
  * - `medium` font-weight: 500
  * - `semi-bold` font-weight: 600
  * - `bold`&mdash;font-weight: 700
  * - `extra-bold`;font-weight: 800.
  */
  fontWeight?: 'light'| 'regular'|'medium' |'semi-bold' |' bold' | 'extra-bold' | any
}

export function Typography({themeColor,color,fontSize,children,size="small",textDecoration="none",...rest}: TypographyProps) {
  return (
    <StyledTypography.Div themeColor={themeColor} color={color} size={size} fontSize={fontSize} textDecoration={textDecoration} {...rest}>
      {children}
    </StyledTypography.Div>
  );
}

Typography.h1 = H1;
Typography.h2 = H2;
Typography.h3 = H3;
Typography.h4 = H4;
Typography.h5 = H5;
Typography.h6 = H6;
Typography.p = P;
Typography.pre = Pre;
Typography.code = Code;
export default Typography;

