import { useState, useRef } from 'react';
import { colors } from '../../utils';
import { IconAlertOutlineLarge } from '@bamboorose/br-components';
import { Popover as KPopover } from '@progress/kendo-react-tooltip';
import { StyledWarningIconListContainer, StyledWarningList } from './styles';
import '../../theme/base-theme.scss';
import { useClickOutside } from '../../utils/hooks';

/* eslint-disable-next-line */
export interface WarningIconListProps {
  /* todo */
  warningItems: string[];
  /* todo */
  position?: 'top' | 'bottom' | 'left' | 'right';
  appendTo?: HTMLElement | null
}

export const WarningIconList = ({
  warningItems,
  position = 'bottom',
  appendTo,
  ...props
}: WarningIconListProps) => {
  const [show, setShow] = useState<boolean>();
  const anchor = useRef(null);

  const handleClick = () => setShow(!show);

  useClickOutside(anchor, () => {
    if (show) setShow(false);
  },appendTo);

  return (
    <StyledWarningIconListContainer>
      <span>{warningItems.length}</span>
      <button type="button" onClick={handleClick} ref={anchor}>
        <IconAlertOutlineLarge
          title="Alert outline icon"
          fill={colors.red}
          fontSize={18}
        />
      </button>

      <KPopover anchor={anchor.current} show={show} appendTo={appendTo} position={position} {...props}>
        <StyledWarningList>
          {warningItems.map((item, i) => {
            return (
              <li key={i}>
                <IconAlertOutlineLarge
                  title="Alert outline icon"
                  fill={colors.red}
                />
                <span>{item}</span>
              </li>
            );
          })}
        </StyledWarningList>
      </KPopover>
    </StyledWarningIconListContainer>
  );
};

export default WarningIconList;
