import { css } from "styled-components"
import { rem } from "."
import { textThemeColor } from "./typography"
import { fontSize, fontWeights, inputHeight } from "./units"
/**
 * constants used to define sizes and themecolor for components proptypes
 * sizes = 'xx-small' |'x-small'| 'small'|'normal' | 'medium' | 'large' |'x-large'|'xx-large'| undefined,
 * themeColor	= "error" | "inverse" | "inherit" | "success" | "dark" | "light" | "primary" | "secondary" | "tertiary" | "info" | "warning"|undefined
 */

export const styledStyles = {
    sizes: (size: string|undefined|null) => {
        switch (size) {
            case "xx-small":
                return css`
              font-size:${fontSize.xxSmall};
              line-height: ${1.375*parseFloat(fontSize.xxSmall)}rem;
            `
            case "x-small":
                return css`
              font-size:${fontSize.xSmall};
              line-height: ${1.375*parseFloat(fontSize.xSmall)}rem;
            `
            case "small":
                return css`
              font-size:${fontSize.small};
              line-height: ${1.375*parseFloat(fontSize.small)}rem;
            `
            case "normal":
                return css`
              font-size:${fontSize.normal};
              line-height: ${1.375*parseFloat(fontSize.normal)}rem;
            `
            case "medium":
                return css`
              font-size:${fontSize.medium};
              line-height: ${1.375*parseFloat(fontSize.medium)}rem;
            `
            case "large":
                return css`
              font-size:${fontSize.large};
              line-height: ${1.25*parseFloat(fontSize.large)}rem;
            `
            case "x-large":
                return css`
              font-size:${fontSize.xLarge};
              line-height: ${1.125*parseFloat(fontSize.xLarge)}rem;
            `
            case "xx-large":
                return css`
              font-size:${fontSize.xxLarge};
              line-height: ${1.125*parseFloat(fontSize.xxLarge)}rem;
            `
            default:
                return css`
                // font-size:${fontSize.small}
              `
        }
    },
    textDecoration:(textDecoration:string) =>{
      switch(textDecoration){
        case "underline": return css`
          text-decoration:underline;
        `
        case "overline": return css`
          text-decoration:overline;
        `
        case "italic": return css`
          font-style:italic;
        `
        case "strikethrough": return css`
          text-decoration:line-through;
        `
        case "none": return css`
          text-decoration:none;
        `
        default: return css`
          text-decoration:none;
        `
      }
    },
   fontSize: ( fontSize:number|undefined ) => !!fontSize && css`
        font-size: ${fontSize}px;
    `,
    fontWeight:(fontWeight:string)=>{
      switch(fontWeight){
        case "light":
          return css`
            font-weight:${fontWeights.light};
          `
        case "regular":
          return css`
          font-weight:${fontWeights.regular};
          `
        case "medium":
            return css`
            font-weight:${fontWeights.medium};
            ` 
        case "semi-bold":
            return css`
            font-weight:${fontWeights.semiBold};
            ` 
        case "bold":
            return css`
            font-weight:${fontWeights.bold};
            ` 
        case "extra-bold":
            return css`
            font-weight:${fontWeights.extraBold};
            `  
        default:
            return css`
            font-weight:${fontWeights.regular};
            ` 
      }
    },
    color: ( color:string |undefined ) => color && css`
        color: ${color}!important;
    `,
    themeColor:(themeColor:string |undefined) =>{
      switch (themeColor) {
          case 'primary':
              return css`
              color: ${textThemeColor.primary}!important;
        `;
          case 'secondary':
              return css`
              color: ${textThemeColor.secondary}!important;
        `;
          case 'tertiary':
              return css`
              color:${textThemeColor.tertiary}!important;
        `;
        case 'error':
              return css`
              color:${textThemeColor.error}!important;
        `;
        case 'inverse':
              return css`
              color:${textThemeColor.inverse}!important;
        `;
        case 'inherit':
              return css`
              color:inherit;
        `;
        case 'success':
          return css`
          color:${textThemeColor.success}!important;
        `;
        case 'dark':
          return css`
          color:${textThemeColor.dark};
        `;
        case 'light':
          return css`
          color:${textThemeColor.light};
        `;
        case 'info':
          return css`
          color:${textThemeColor.info}!important;
        `;
        case 'warning':
          return css`
          color:${textThemeColor.warning}!important;
        `;
          default:
              return css`
              color: ${textThemeColor.default}!important;
        `;
      }
    },
    inputSizes: ( size:string|undefined|null ) => {
      switch (size) {
          case 'xx-small':
            return css`
            min-height: ${inputHeight.xxsm};
            padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
            font-size: ${fontSize.xxSmall};
            & > span.k-clear-value{
              height: auto;
              width:auto;
              >span{
                font-size: ${fontSize.small};
              }
            }
            & > button.k-button{
              padding:0;
              height: auto;
              width:auto;
              >span.k-icon {
                min-height:auto;
                height: auto;
                width:auto;
                font-size: ${fontSize.small};
              }
            }
            & input{
              padding:0!important;
              &::placeholder{
                font-size:${fontSize.xxSmall};
              }
            }
            `;
          case 'x-small':
            return css`
              min-height: ${inputHeight.xsm};
              padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
              font-size: ${fontSize.xSmall};
              & > span.k-clear-value{
                height: auto;
                width:auto;
                >span{
                  font-size: ${fontSize.small};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.small};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  font-size:${fontSize.xSmall};
                }
              }
            `;
          case 'small':
            return css`
              min-height: ${inputHeight.sm};
              padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
              font-size: ${fontSize.small};
              & > span.k-clear-value{
                height: auto;
                width:auto;
                >span{
                  font-size: ${fontSize.normal};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.small};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  // font-size:${fontSize.small};
                }
              }
            `;
          case 'normal':
            return css`
              min-height: ${inputHeight.normal};
              padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
              font-size: ${fontSize.normal};
              & > span.k-clear-value{
                height: auto;
                width:auto;
                >span{
                  font-size: ${fontSize.normal};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.normal};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  font-size:${fontSize.normal};
                }
              }
            `;
          case 'medium':
            return css`
              min-height: ${inputHeight.md};
              padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
              font-size: ${fontSize.medium};
              & > span.k-clear-value{
                height: auto;
                width:auto;
                >span{
                  font-size: ${fontSize.medium};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.medium};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  font-size:${fontSize.medium};
                }
              }
            `;
          case 'large':
            return css`
              min-height: ${inputHeight.lg};
              padding: ${rem(4)} ${rem(13)} ${rem(4)} ${rem(16)};
              font-size: ${fontSize.large};
              & > span.k-clear-value{
                height: auto;
                width:auto;
                >span{
                  font-size: ${fontSize.large};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.large};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  font-size:${fontSize.large};
                }
              }
            `;
            case 'x-large':
              return css`
                min-height: ${inputHeight.xlg};
                padding: ${rem(4)} ${rem(15)} ${rem(4)} ${rem(18)};
                font-size: ${fontSize.xLarge};
                & > span.k-clear-value{
                  height: auto;
                  width:auto;
                  >span{
                    font-size: ${fontSize.xLarge};
                  }
                }
                & > button.k-button{
                  padding:0;
                  height: auto;
                  width:auto;
                  >span.k-icon {
                    min-height:auto;
                    height: auto;
                    width:auto;
                    font-size: ${fontSize.xLarge};
                  }
                }
                & input{
                  padding:0!important;
                  &::placeholder{
                    font-size:${fontSize.xLarge};
                  }
                }
              `;
            case 'xx-large':
              return css`
                min-height: ${inputHeight.xxlg};
                padding: ${rem(4)} ${rem(17)} ${rem(4)} ${rem(20)};
                font-size: ${fontSize.xxLarge};
                & > span.k-clear-value{
                  height: auto;
                  width:auto;
                  >span{
                    font-size: ${fontSize.xxLarge};
                  }
                }
                & > button.k-button{
                  padding:0;
                  height: auto;
                  width:auto;
                  >span.k-icon {
                    min-height:auto;
                    height: auto;
                    width:auto;
                    font-size: ${fontSize.xxLarge};
                  }
                }
                & input{
                  padding:0!important;
                  &::placeholder{
                    font-size:${fontSize.xxLarge};
                  }
                }
              `;
          default:
            return css`
              min-height: ${inputHeight.sm};
              padding: ${rem(4)} ${rem(7)} ${rem(4)} ${rem(10)};
              font-size: ${fontSize.small};
              & > span.k-clear-value{
                height: ${inputHeight.sm};
                >span{
                  font-size: ${fontSize.small};
                }
              }
              & > button.k-button{
                padding:0;
                height: auto;
                width:auto;
                >span.k-icon {
                  min-height:auto;
                  height: auto;
                  width:auto;
                  font-size: ${fontSize.small};
                }
              }
              & input{
                padding:0!important;
                &::placeholder{
                  font-size:${fontSize.small};
                }
              }
            `;
        }
    }
}
